@@ -3,7 +3,7 @@ EXTRACTRC=`which extractrc`
 # XGETTEXT="`which xgettext` --kde -ki18n --no-location -s "
 XGETTEXT="`which xgettext` -s "
 podir=`pwd`/po
-kdenlive_subdirs="src src/widgets renderer"
+kdenlive_subdirs="src src/widgets renderer plugins"
 
 
 kde_inc=${includedir:-${KDEDIR:-@CMAKE_INSTALL_PREFIX@}/include/kde}/kde.pot
@@ -14,7 +14,7 @@ else
    kde_inc=""
 fi
 
-$EXTRACTRC --tag=name --tag=description --tag=label effects/*.xml data/*.rc >> rc.cpp || exit 11
+$EXTRACTRC --tag=name --tag=description --tag=label --tag=comment --tag=paramlistdisplay effects/*.xml data/*.rc >> rc.cpp || exit 11
 
 $EXTRACTRC `find $kdenlive_subdirs -name \*.ui` >> rc.cpp || exit 11
 $EXTRACTRC `find $kdenlive_subdirs -name \*.rc` >> rc.cpp || exit 11
