@@ -57,6 +57,8 @@ public:
     double selectedKeyFrameValue() const;
     double editedKeyFrameValue() const;
     double keyFrameFactor() const;
+    /** @brief Returns the number of keyframes the selected effect has. */
+    int keyFrameNumber() const;
     ItemInfo info() const;
     CustomTrackScene* projectScene();
     void updateRectGeometry();
@@ -65,7 +67,7 @@ public:
     bool isItemLocked() const;
     void closeAnimation();
 
-    virtual  OPERATIONTYPE operationMode(QPointF pos) = 0;
+    virtual OPERATIONTYPE operationMode(QPointF pos) = 0;
     virtual GenTime startPos() const ;
     virtual void setTrack(int track);
     virtual GenTime endPos() const ;
@@ -99,8 +101,14 @@ protected:
         GenTime m_startPos;*/
     GenTime m_maxDuration;
     QMap <int, int> m_keyframes;
+    /** @brief Strech factor so that keyframes display on the full clip height. */
     double m_keyframeFactor;
+    /** @brief Offset factor so that keyframes minimum value are displaed at the bottom of the clip. */
+    double m_keyframeOffset;
+    /** @brief Default reset value for keyframe. */
     double m_keyframeDefault;
+    /** The (keyframe) parameter that is visible and editable in timeline (on the clip) */
+    int m_visibleParam;
     double m_fps;
     //QRect visibleRect();
     void drawKeyFrames(QPainter *painter, QRectF exposedRect);
