@@ -27,6 +27,9 @@
 #include "kdenlivesettings.h"
 #include "kthumb.h"
 #include "profilesdialog.h"
+#ifdef QJSON
+#include "rotoscoping/rotowidget.h"
+#endif
 
 #include <KDebug>
 #include <KIcon>
@@ -61,7 +64,8 @@ ClipItem::ClipItem(DocClipBase *clip, ItemInfo info, double fps, double speed, i
     setPos(info.startPos.frames(fps), (double)(info.track * KdenliveSettings::trackheight()) + 1);
 
     // set speed independant info
-    if (m_speed <= 0 && m_speed > -1) m_speed = 1.0;
+    if (m_speed <= 0 && m_speed > -1)
+        m_speed = -1.0;
     m_speedIndependantInfo = m_info;
     m_speedIndependantInfo.cropStart = GenTime((int)(m_info.cropStart.frames(m_fps) * qAbs(m_speed)), m_fps);
     m_speedIndependantInfo.cropDuration = GenTime((int)(m_info.cropDuration.frames(m_fps) * qAbs(m_speed)), m_fps);
@@ -69,10 +73,11 @@ ClipItem::ClipItem(DocClipBase *clip, ItemInfo info, double fps, double speed, i
     m_videoPix = KIcon("kdenlive-show-video").pixmap(QSize(16, 16));
     m_audioPix = KIcon("kdenlive-show-audio").pixmap(QSize(16, 16));
 
-    if (m_speed == 1.0) m_clipName = m_clip->name();
-    else {
+    if (m_speed == 1.0)
+        m_clipName = m_clip->name();
+    else
         m_clipName = m_clip->name() + " - " + QString::number(m_speed * 100, 'f', 0) + '%';
-    }
+
     m_producer = m_clip->getId();
     m_clipType = m_clip->clipType();
     //m_cropStart = info.cropStart;
@@ -230,7 +235,9 @@ void ClipItem::initEffect(QDomElement effect, int diff)
     QDomNodeList params = effect.elementsByTagName("parameter");
     for (int i = 0; i < params.count(); i++) {
         QDomElement e = params.item(i).toElement();
-        kDebug() << "// init eff: " << e.attribute("name");
+
+        if (e.isNull())
+            continue;
 
         // Check if this effect has a variable parameter
         if (e.attribute("default").startsWith('%')) {
@@ -241,14 +248,15 @@ void ClipItem::initEffect(QDomElement effect, int diff)
             }
         }
 
-        if (!e.isNull() && (e.attribute("type") == "keyframe" || e.attribute("type") == "simplekeyframe")) {
-            QString def = e.attribute("default");
+        if (effect.attribute("id") == "crop") {
+            // default use_profile to 1 for clips with proxies to avoid problems when rendering
+            if (e.attribute("name") == "use_profile" && !(m_clip->getProperty("proxy").isEmpty() || m_clip->getProperty("proxy") == "-"))
+                e.setAttribute("value", "1");
+        }
+
+        if ((e.attribute("type") == "keyframe" || e.attribute("type") == "simplekeyframe") && e.attribute("keyframes").isEmpty()) {
             // Effect has a keyframe type parameter, we need to set the values
-            if (e.attribute("keyframes").isEmpty()) {
-                e.setAttribute("keyframes", QString::number(cropStart().frames(m_fps)) + ':' + def + ';' + QString::number((cropStart() + cropDuration()).frames(m_fps) - 1) + ':' + def);
-                kDebug() << "///// EFFECT KEYFRAMES INITED: " << e.attribute("keyframes");
-                //break;
-            }
+            e.setAttribute("keyframes", QString::number(cropStart().frames(m_fps)) + ':' + e.attribute("default"));
         }
     }
     if (effect.attribute("tag") == "volume" || effect.attribute("tag") == "brightness") {
@@ -387,13 +395,15 @@ void ClipItem::setKeyframes(const int ix, const QStringList keyframes)
     int keyframeParams = 0;
     for (int i = 0; i < params.count(); i++) {
         QDomElement e = params.item(i).toElement();
-        if (!e.isNull() && (e.attribute("type") == "keyframe" || e.attribute("type") == "simplekeyframe")) {
+        if (!e.isNull() && (e.attribute("type") == "keyframe" || e.attribute("type") == "simplekeyframe") && e.attribute("intimeline") == "1") {
             e.setAttribute("keyframes", keyframes.at(keyframeParams));
             if (ix == m_selectedEffect && keyframeParams == 0) {
                 m_keyframes.clear();
+                m_visibleParam = i;
                 double max = e.attribute("max").toDouble();
                 double min = e.attribute("min").toDouble();
                 m_keyframeFactor = 100.0 / (max - min);
+                m_keyframeOffset = min;
                 m_keyframeDefault = e.attribute("default").toDouble();
                 m_selectedKeyframe = 0;
                 // parse keyframes
@@ -417,32 +427,35 @@ void ClipItem::setSelectedEffect(const int ix)
 {
     m_selectedEffect = ix;
     QDomElement effect = effectAt(m_selectedEffect);
-    if (effect.isNull() == false) {
+    if (!effect.isNull() && effect.attribute("disable") != "1") {
         QDomNodeList params = effect.elementsByTagName("parameter");
-        if (effect.attribute("disable") != "1")
-            for (int i = 0; i < params.count(); i++) {
-                QDomElement e = params.item(i).toElement();
-                if (!e.isNull() && (e.attribute("type") == "keyframe" || e.attribute("type") == "simplekeyframe")) {
-                    m_keyframes.clear();
-                    double max = e.attribute("max").toDouble();
-                    double min = e.attribute("min").toDouble();
-                    m_keyframeFactor = 100.0 / (max - min);
-                    m_keyframeDefault = e.attribute("default").toDouble();
-                    m_selectedKeyframe = 0;
+        for (int i = 0; i < params.count(); i++) {
+            QDomElement e = params.item(i).toElement();
+            if (!e.isNull() && (e.attribute("type") == "keyframe" || e.attribute("type") == "simplekeyframe") && e.attribute("intimeline") == "1") {
+                m_keyframes.clear();
+                m_visibleParam = i;
+                double max = e.attribute("max").toDouble();
+                double min = e.attribute("min").toDouble();
+                m_keyframeFactor = 100.0 / (max - min);
+                m_keyframeOffset = min;
+                m_keyframeDefault = e.attribute("default").toDouble();
+                m_selectedKeyframe = 0;
 
-                    // parse keyframes
-                    const QStringList keyframes = e.attribute("keyframes").split(';', QString::SkipEmptyParts);
-                    foreach(const QString &str, keyframes) {
-                        int pos = str.section(':', 0, 0).toInt();
-                        double val = str.section(':', 1, 1).toDouble();
-                        m_keyframes[pos] = val;
-                    }
-                    if (m_keyframes.find(m_editedKeyframe) == m_keyframes.end()) m_editedKeyframe = -1;
-                    update();
-                    return;
+                // parse keyframes
+                const QStringList keyframes = e.attribute("keyframes").split(';', QString::SkipEmptyParts);
+                foreach(const QString &str, keyframes) {
+                    int pos = str.section(':', 0, 0).toInt();
+                    double val = str.section(':', 1, 1).toDouble();
+                    m_keyframes[pos] = val;
                 }
+                if (m_keyframes.find(m_editedKeyframe) == m_keyframes.end())
+                    m_editedKeyframe = -1;
+                update();
+                return;
             }
+        }
     }
+
     if (!m_keyframes.isEmpty()) {
         m_keyframes.clear();
         update();
@@ -469,23 +482,19 @@ void ClipItem::updateKeyframeEffect()
     QDomElement effect = getEffectAt(m_selectedEffect);
     if (effect.attribute("disable") == "1") return;
     QDomNodeList params = effect.elementsByTagName("parameter");
+    QDomElement e = params.item(m_visibleParam).toElement();
 
-    for (int i = 0; i < params.count(); i++) {
-        QDomElement e = params.item(i).toElement();
-        if (!e.isNull() && (e.attribute("type") == "keyframe" || e.attribute("type") == "simplekeyframe")) {
-            QString keyframes;
-            if (m_keyframes.count() > 0) {
-                QMap<int, int>::const_iterator i = m_keyframes.constBegin();
-                while (i != m_keyframes.constEnd()) {
-                    keyframes.append(QString::number(i.key()) + ':' + QString::number(i.value()) + ';');
-                    ++i;
-                }
+    if (!e.isNull()) {
+        QString keyframes;
+        if (m_keyframes.count() > 0) {
+            QMap<int, int>::const_iterator i = m_keyframes.constBegin();
+            while (i != m_keyframes.constEnd()) {
+                keyframes.append(QString::number(i.key()) + ':' + QString::number(i.value()) + ';');
+                ++i;
             }
-            // Effect has a keyframe type parameter, we need to set the values
-            //kDebug() << ":::::::::::::::   SETTING EFFECT KEYFRAMES: " << keyframes;
-            e.setAttribute("keyframes", keyframes);
-            break;
         }
+        // Effect has a keyframe type parameter, we need to set the values
+        e.setAttribute("keyframes", keyframes);
     }
 }
 
@@ -506,7 +515,7 @@ void ClipItem::resetThumbs(bool clearExistingThumbs)
 }
 
 
-void ClipItem::refreshClip(bool checkDuration)
+void ClipItem::refreshClip(bool checkDuration, bool forceResetThumbs)
 {
     if (checkDuration && (m_maxDuration != m_clip->maxDuration())) {
         m_maxDuration = m_clip->maxDuration();
@@ -527,7 +536,8 @@ void ClipItem::refreshClip(bool checkDuration)
         QString colour = m_clip->getProperty("colour");
         colour = colour.replace(0, 2, "#");
         m_baseColor = QColor(colour.left(7));
-    } else resetThumbs(checkDuration);
+        update();
+    } else resetThumbs(forceResetThumbs);
 }
 
 void ClipItem::slotFetchThumbs()
@@ -943,36 +953,19 @@ OPERATIONTYPE ClipItem::operationMode(QPointF pos)
     if (rect.height() < 30) addtransitionOffset = 0;
 
     if (qAbs((int)(pos.x() - (rect.x() + m_startFade))) < maximumOffset  && qAbs((int)(pos.y() - rect.y())) < 6) {
-        if (m_startFade == 0) setToolTip(i18n("Add audio fade"));
-        // xgettext:no-c-format
-        else setToolTip(i18n("Audio fade duration: %1s", GenTime(m_startFade, m_fps).seconds()));
         return FADEIN;
     } else if (pos.x() - rect.x() < maximumOffset && (rect.bottom() - pos.y() > addtransitionOffset)) {
-        // xgettext:no-c-format
-        setToolTip(i18n("Crop from start: %1s", cropStart().seconds()));
         return RESIZESTART;
     } else if (qAbs((int)(pos.x() - (rect.x() + rect.width() - m_endFade))) < maximumOffset && qAbs((int)(pos.y() - rect.y())) < 6) {
-        if (m_endFade == 0) setToolTip(i18n("Add audio fade"));
-        // xgettext:no-c-format
-        else setToolTip(i18n("Audio fade duration: %1s", GenTime(m_endFade, m_fps).seconds()));
         return FADEOUT;
     } else if ((rect.right() - pos.x() < maximumOffset) && (rect.bottom() - pos.y() > addtransitionOffset)) {
-        // xgettext:no-c-format
-        setToolTip(i18n("Clip duration: %1s", cropDuration().seconds()));
         return RESIZEEND;
     } else if ((pos.x() - rect.x() < 16 / scale) && (rect.bottom() - pos.y() <= addtransitionOffset)) {
-        setToolTip(i18n("Add transition"));
         return TRANSITIONSTART;
     } else if ((rect.right() - pos.x() < 16 / scale) && (rect.bottom() - pos.y() <= addtransitionOffset)) {
-        setToolTip(i18n("Add transition"));
         return TRANSITIONEND;
     }
-    QString tooltip = "<b>" + m_clipName + "</b>";
-    if (!baseClip()->fileURL().isEmpty())
-        tooltip.append("<br />" + baseClip()->fileURL().path());
-    if (!baseClip()->description().isEmpty())
-        tooltip.append("<br />" + baseClip()->description());
-    setToolTip(tooltip);
+
     return MOVE;
 }
 
@@ -1108,22 +1101,18 @@ void ClipItem::setFadeIn(int pos)
 {
     if (pos == m_startFade) return;
     int oldIn = m_startFade;
-    if (pos < 0) pos = 0;
-    if (pos > cropDuration().frames(m_fps)) pos = (int)(cropDuration().frames(m_fps));
-    m_startFade = pos;
+    m_startFade = qBound(0, pos, (int)cropDuration().frames(m_fps));
     QRectF rect = boundingRect();
-    update(rect.x(), rect.y(), qMax(oldIn, pos), rect.height());
+    update(rect.x(), rect.y(), qMax(oldIn, m_startFade), rect.height());
 }
 
 void ClipItem::setFadeOut(int pos)
 {
     if (pos == m_endFade) return;
     int oldOut = m_endFade;
-    if (pos < 0) pos = 0;
-    if (pos > cropDuration().frames(m_fps)) pos = (int)(cropDuration().frames(m_fps));
-    m_endFade = pos;
+    m_endFade = qBound(0, pos, (int)cropDuration().frames(m_fps));
     QRectF rect = boundingRect();
-    update(rect.x() + rect.width() - qMax(oldOut, pos), rect.y(), qMax(oldOut, pos), rect.height());
+    update(rect.x() + rect.width() - qMax(oldOut, m_endFade), rect.y(), qMax(oldOut, m_endFade), rect.height());
 
 }
 
@@ -1209,56 +1198,6 @@ void ClipItem::resizeEnd(int posx)
     }
 }
 
-
-bool ClipItem::checkEffectsKeyframesPos(const int previous, const int current, bool fromStart)
-{
-    bool effModified = false;
-    for (int i = 0; i < m_effectList.count(); i++) {
-        QDomElement effect = m_effectList.at(i);
-        QDomNodeList params = effect.elementsByTagName("parameter");
-        for (int j = 0; j < params.count(); j++) {
-            bool modified = false;
-            QDomElement e = params.item(j).toElement();
-            if (e.isNull())
-                continue;
-            if (e.attribute("type") == "keyframe" || e.attribute("type") == "simplekeyframe") {
-                // parse keyframes and adjust values
-                const QStringList keyframes = e.attribute("keyframes").split(';', QString::SkipEmptyParts);
-                QMap <int, double> kfr;
-                int pos;
-                double val;
-                foreach(const QString &str, keyframes) {
-                    pos = str.section(':', 0, 0).toInt();
-                    val = str.section(':', 1, 1).toDouble();
-                    if (pos == previous) {
-                        // first or last keyframe
-                        kfr[current] = val;
-                        modified = true;
-                    } else {
-                        if ((fromStart && pos >= current) || (!fromStart && pos <= current)) {
-                            // only keyframes in range
-                            kfr[pos] = val;
-                            modified = true;
-                        }
-                    }
-                }
-                if (modified) {
-                    effModified = true;
-                    QString newkfr;
-                    QMap<int, double>::const_iterator k = kfr.constBegin();
-                    while (k != kfr.constEnd()) {
-                        newkfr.append(QString::number(k.key()) + ':' + QString::number(k.value()) + ';');
-                        ++k;
-                    }
-                    e.setAttribute("keyframes", newkfr);
-                }
-            }
-        }
-    }
-    if (effModified && m_selectedEffect >= 0) setSelectedEffect(m_selectedEffect);
-    return effModified;
-}
-
 //virtual
 QVariant ClipItem::itemChange(GraphicsItemChange change, const QVariant &value)
 {
@@ -1418,16 +1357,10 @@ EffectsParameterList ClipItem::addEffect(const QDomElement effect, bool /*animat
     if (effectId.isEmpty()) effectId = effect.attribute("tag");
     parameters.addParam("id", effectId);
 
-    // special case: the affine effect needs in / out points
+    // special case: the affine effect needs in / out points
     if (effectId == "pan_zoom") {
-        int start = cropStart().frames(m_fps);
-        int end = (cropStart() + cropDuration()).frames(m_fps);
-        if (start < 0) {
-            end -= start;
-            start = 0;
-        }
-        parameters.addParam("in", QString::number(start));
-        parameters.addParam("out", QString::number(end));
+        parameters.addParam("in", QString::number(cropStart().frames(m_fps)));
+        parameters.addParam("out", QString::number((cropStart() + cropDuration()).frames(m_fps)));
     }
 
     QDomNodeList params = effect.elementsByTagName("parameter");
@@ -1440,8 +1373,8 @@ EffectsParameterList ClipItem::addEffect(const QDomElement effect, bool /*animat
                 double factor = e.attribute("factor", "1").toDouble();
                 if (factor != 1) {
                     for (int j = 0; j < values.count(); j++) {
-                        QString pos = values.at(j).section(":", 0, 0);
-                        double val = values.at(j).section(":", 1, 1).toDouble() / factor;
+                        QString pos = values.at(j).section(':', 0, 0);
+                        double val = values.at(j).section(':', 1, 1).toDouble() / factor;
                         values[j] = pos + "=" + QString::number(val);
                     }
                 }
@@ -1584,7 +1517,7 @@ void ClipItem::setSpeed(const double speed, const int strobe)
 {
     m_speed = speed;
     if (m_speed <= 0 && m_speed > -1)
-        m_speed = 1.0;
+        m_speed = -1.0;
     m_strobe = strobe;
     if (m_speed == 1.0) m_clipName = baseClip()->name();
     else m_clipName = baseClip()->name() + " - " + QString::number(speed * 100, 'f', 0) + '%';
@@ -1617,7 +1550,7 @@ const ItemInfo ClipItem::speedIndependantInfo() const
 //virtual
 void ClipItem::dropEvent(QGraphicsSceneDragDropEvent * event)
 {
-    const QString effects = QString(event->mimeData()->data("kdenlive/effectslist"));
+    const QString effects = QString::fromUtf8(event->mimeData()->data("kdenlive/effectslist"));
     QDomDocument doc;
     doc.setContent(effects, true);
     const QDomElement e = doc.documentElement();
@@ -1637,7 +1570,7 @@ void ClipItem::dragEnterEvent(QGraphicsSceneDragDropEvent *event)
 
 void ClipItem::dragLeaveEvent(QGraphicsSceneDragDropEvent *event)
 {
-    Q_UNUSED(event);
+    Q_UNUSED(event)
 }
 
 void ClipItem::addTransition(Transition* t)
@@ -1687,24 +1620,33 @@ void ClipItem::insertKeyframe(QDomElement effect, int pos, int val)
     QDomNodeList params = effect.elementsByTagName("parameter");
     for (int i = 0; i < params.count(); i++) {
         QDomElement e = params.item(i).toElement();
-        QString kfr = e.attribute("keyframes");
-        const QStringList keyframes = kfr.split(';', QString::SkipEmptyParts);
-        QStringList newkfr;
-        bool added = false;
-        foreach(const QString &str, keyframes) {
-            int kpos = str.section(':', 0, 0).toInt();
-            double newval = str.section(':', 1, 1).toDouble();
-            if (kpos < pos) {
-                newkfr.append(str);
-            } else if (!added) {
-                if (i == 0) newkfr.append(QString::number(pos) + ":" + QString::number(val));
-                else newkfr.append(QString::number(pos) + ":" + QString::number(newval));
-                if (kpos > pos) newkfr.append(str);
-                added = true;
-            } else newkfr.append(str);
+        if (!e.isNull() && (e.attribute("type") == "keyframe" || e.attribute("type") == "simplekeyframe")) {
+            QString kfr = e.attribute("keyframes");
+            const QStringList keyframes = kfr.split(';', QString::SkipEmptyParts);
+            QStringList newkfr;
+            bool added = false;
+            foreach(const QString &str, keyframes) {
+                int kpos = str.section(':', 0, 0).toInt();
+                double newval = str.section(':', 1, 1).toDouble();
+                if (kpos < pos) {
+                    newkfr.append(str);
+                } else if (!added) {
+                    if (i == m_visibleParam)
+                        newkfr.append(QString::number(pos) + ":" + QString::number(val));
+                    else
+                        newkfr.append(QString::number(pos) + ":" + QString::number(newval));
+                    if (kpos > pos) newkfr.append(str);
+                    added = true;
+                } else newkfr.append(str);
+            }
+            if (!added) {
+                if (i == m_visibleParam)
+                    newkfr.append(QString::number(pos) + ":" + QString::number(val));
+                else
+                    newkfr.append(QString::number(pos) + ":" + e.attribute("default"));
+            }
+            e.setAttribute("keyframes", newkfr.join(";"));
         }
-        if (!added) newkfr.append(QString::number(pos) + ":" + QString::number(val));
-        e.setAttribute("keyframes", newkfr.join(";"));
     }
 }
 
@@ -1717,20 +1659,24 @@ void ClipItem::movedKeyframe(QDomElement effect, int oldpos, int newpos, double
     int end = (cropStart() + cropDuration()).frames(m_fps) - 1;
     for (int i = 0; i < params.count(); i++) {
         QDomElement e = params.item(i).toElement();
-        QString kfr = e.attribute("keyframes");
-        const QStringList keyframes = kfr.split(';', QString::SkipEmptyParts);
-        QStringList newkfr;
-        foreach(const QString &str, keyframes) {
-            if (str.section(':', 0, 0).toInt() != oldpos) {
-                newkfr.append(str);
-            } else if (newpos != -1) {
-                newpos = qMax(newpos, start);
-                newpos = qMin(newpos, end);
-                if (i == 0) newkfr.append(QString::number(newpos) + ":" + QString::number(value));
-                else newkfr.append(QString::number(newpos) + ":" + str.section(':', 1, 1));
+        if (!e.isNull() && (e.attribute("type") == "keyframe" || e.attribute("type") == "simplekeyframe")) {
+            QString kfr = e.attribute("keyframes");
+            const QStringList keyframes = kfr.split(';', QString::SkipEmptyParts);
+            QStringList newkfr;
+            foreach(const QString &str, keyframes) {
+                if (str.section(':', 0, 0).toInt() != oldpos) {
+                    newkfr.append(str);
+                } else if (newpos != -1) {
+                    newpos = qMax(newpos, start);
+                    newpos = qMin(newpos, end);
+                    if (i == m_visibleParam)
+                        newkfr.append(QString::number(newpos) + ":" + QString::number(value));
+                    else
+                        newkfr.append(QString::number(newpos) + ":" + str.section(':', 1, 1));
+                }
             }
+            e.setAttribute("keyframes", newkfr.join(";"));
         }
-        e.setAttribute("keyframes", newkfr.join(";"));
     }
 
     updateKeyframes(effect);
@@ -1742,7 +1688,11 @@ void ClipItem::updateKeyframes(QDomElement effect)
     m_keyframes.clear();
     // parse keyframes
     QDomNodeList params = effect.elementsByTagName("parameter");
-    QDomElement e = params.item(0).toElement();
+    QDomElement e = params.item(m_visibleParam).toElement();
+    if (e.attribute("intimeline") != "1") {
+        setSelectedEffect(m_selectedEffect);
+        return;
+    }
     const QStringList keyframes = e.attribute("keyframes").split(';', QString::SkipEmptyParts);
     foreach(const QString &str, keyframes) {
         int pos = str.section(':', 0, 0).toInt();
@@ -1767,9 +1717,9 @@ void ClipItem::doGetIntraThumbs(QPainter *painter, const QPointF startPos, int o
     }
     QPixmap p;
     for (int i = start; i <= end; i++) {
-        if (!view->pixmapCache->find(m_clip->fileURL().path() + "%" + QString::number(i), p)) {
+        if (!view->m_pixmapCache->find(m_clip->fileURL().path() + "%" + QString::number(i), p)) {
             p = m_clip->thumbProducer()->extractImage(i, twidth, theight);
-            view->pixmapCache->insert(m_clip->fileURL().path() + "%" + QString::number(i), p);
+            view->m_pixmapCache->insert(m_clip->fileURL().path() + "%" + QString::number(i), p);
         }
         painter->drawPixmap(startPos + QPointF(twidth *(i - offset), 0), p);
     }
@@ -1787,64 +1737,7 @@ QList <int> ClipItem::updatePanZoom(int width, int height, int cut)
                 continue;
             if (e.attribute("type") == "geometry" && !e.hasAttribute("fixed")) {
                 effectPositions << i;
-
-                int in = cropStart().frames(fps());
-                int out = in + cropDuration().frames(fps());
-                if (in < 0) {
-                    out -= in;
-                    in = 0;
-                }
-                int dur = out - in - 1;
-
-                effect.setAttribute("in", in);
-                effect.setAttribute("out", out);
-
-                Mlt::Geometry geometry(e.attribute("value").toUtf8().data(), dur, width, height);
-                Mlt::GeometryItem item;
-                bool endFrameAdded = false;
-                if (cut == 0) {
-                    while (!geometry.next_key(&item, dur)) {
-                        if (!endFrameAdded) {
-                            // add keyframe at the end with interpolated value
-
-                            // but only once ;)
-                            endFrameAdded = true;
-
-                            Mlt::GeometryItem endItem;
-                            Mlt::GeometryItem interp;
-                            geometry.fetch(&interp, dur - 1);
-                            endItem.frame(dur - 1);
-                            endItem.x(interp.x());
-                            endItem.y(interp.y());
-                            endItem.w(interp.w());
-                            endItem.h(interp.h());
-                            endItem.mix(interp.mix());
-                            geometry.insert(&endItem);
-                        }
-                        geometry.remove(item.frame());
-                    }
-                } else {
-                    Mlt::Geometry origGeometry(e.attribute("value").toUtf8().data(), dur, width, height);
-                    // remove keyframes before cut point
-                    while (!geometry.prev_key(&item, cut - 1) && item.frame() < cut)
-                        geometry.remove(item.frame());
-
-                    // add a keyframe at new pos 0
-                    origGeometry.fetch(&item, cut);
-                    item.frame(0);
-                    geometry.insert(&item);
-
-                    // move exisiting keyframes by -cut
-                    while (!origGeometry.next_key(&item, cut)) {
-                        geometry.remove(item.frame());
-                        origGeometry.remove(item.frame());
-                        item.frame(item.frame() - cut);
-                        geometry.insert(&item);
-                    }
-                    
-                }
-
-                e.setAttribute("value", geometry.serialise());
+//                 updateGeometryKeyframes(effect, j, width, height, cut);
             }
         }
     }
@@ -1852,4 +1745,177 @@ QList <int> ClipItem::updatePanZoom(int width, int height, int cut)
     return effectPositions;
 }
 
+Mlt::Producer *ClipItem::getProducer(int track, bool trackSpecific)
+{
+    if (isAudioOnly())
+        return m_clip->audioProducer(track);
+    else if (isVideoOnly())
+        return m_clip->videoProducer();
+    else
+        return m_clip->producer(trackSpecific ? track : -1);
+}
+
+QMap<int, QDomElement> ClipItem::adjustEffectsToDuration(int width, int height, ItemInfo oldInfo)
+{
+    QMap<int, QDomElement> effects;
+    for (int i = 0; i < m_effectList.count(); i++) {
+        QDomElement effect = m_effectList.at(i);
+
+        if (effect.attribute("id").startsWith("fade")) {
+            QString id = effect.attribute("id");
+            int in = EffectsList::parameter(effect, "in").toInt();
+            int out = EffectsList::parameter(effect, "out").toInt();
+            int clipEnd = (cropStart() + cropDuration()).frames(m_fps);
+            if (id == "fade_from_black" || id == "fadein") {
+                if (in != cropStart().frames(m_fps)) {
+                    effects[i] = effect.cloneNode().toElement();
+                    int diff = in - cropStart().frames(m_fps);
+                    in -= diff;
+                    out -= diff;
+                    EffectsList::setParameter(effect, "in", QString::number(in));
+                    EffectsList::setParameter(effect, "out", QString::number(out));
+                }
+                if (out > clipEnd) {
+                    if (!effects.contains(i))
+                        effects[i] = effect.cloneNode().toElement();
+                    EffectsList::setParameter(effect, "out", QString::number(clipEnd));
+                }
+                if (effects.contains(i))
+                    setFadeIn(out - in);
+            } else {
+                if (out != clipEnd) {
+                    effects[i] = effect.cloneNode().toElement();
+                    int diff = out - clipEnd;
+                    in -= diff;
+                    out -= diff;
+                    EffectsList::setParameter(effect, "in", QString::number(in));
+                    EffectsList::setParameter(effect, "out", QString::number(out));
+                }
+                if (in < cropStart().frames(m_fps)) {
+                    if (!effects.contains(i))
+                        effects[i] = effect.cloneNode().toElement();
+                    EffectsList::setParameter(effect, "in", QString::number(cropStart().frames(m_fps)));
+                }
+                if (effects.contains(i))
+                    setFadeOut(out - in);
+            }
+            continue;
+        } else if (effect.attribute("id") == "freeze" && cropStart() != oldInfo.cropStart) {
+            effects[i] = effect.cloneNode().toElement();
+            int diff = (oldInfo.cropStart - cropStart()).frames(m_fps);
+            int frame = EffectsList::parameter(effect, "frame").toInt();
+            EffectsList::setParameter(effect, "frame", QString::number(frame - diff));
+            continue;
+        }
+
+        QDomNodeList params = effect.elementsByTagName("parameter");
+        for (int j = 0; j < params.count(); j++) {
+            QDomElement param = params.item(j).toElement();
+
+            QString type = param.attribute("type");
+            if (type == "geometry" && !param.hasAttribute("fixed")) {
+                if (!effects.contains(i))
+                    effects[i] = effect.cloneNode().toElement();
+                updateGeometryKeyframes(effect, j, width, height, oldInfo);
+            } else if (type == "simplekeyframe" || type == "keyframe") {
+                if (!effects.contains(i))
+                    effects[i] = effect.cloneNode().toElement();
+                updateNormalKeyframes(param);
+#ifdef QJSON
+            } else if (type == "roto-spline") {
+                if (!effects.contains(i))
+                    effects[i] = effect.cloneNode().toElement();
+                QString value = param.attribute("value");
+                if (adjustRotoDuration(&value, cropStart().frames(m_fps), (cropStart() + cropDuration()).frames(m_fps) - 1))
+                    param.setAttribute("value", value);
+#endif    
+            }
+        }
+    }
+    return effects;
+}
+
+bool ClipItem::updateNormalKeyframes(QDomElement parameter)
+{
+    int in = cropStart().frames(m_fps);
+    int out = (cropStart() + cropDuration()).frames(m_fps) - 1;
+
+    const QStringList data = parameter.attribute("keyframes").split(';', QString::SkipEmptyParts);
+    QMap <int, double> keyframes;
+    foreach (QString keyframe, data)
+        keyframes[keyframe.section(':', 0, 0).toInt()] = keyframe.section(':', 1, 1).toDouble();
+
+
+    QMap<int, double>::iterator i = keyframes.end();
+    int lastPos = -1;
+    double lastValue = 0;
+    qreal relPos;
+
+    /*
+     * Take care of resize from start
+     */
+    bool startFound = false;
+    while (i-- != keyframes.begin()) {
+        if (i.key() < in && !startFound) {
+            startFound = true;
+            if (lastPos < 0) {
+                keyframes[in] = i.value();
+            } else {
+                relPos = (in - i.key()) / (qreal)(lastPos - i.key() + 1);
+                keyframes[in] = i.value() + (lastValue - i.value()) * relPos;
+            }
+        }
+        lastPos = i.key();
+        lastValue = i.value();
+        if (startFound)
+            i = keyframes.erase(i);
+    }
+
+    /*
+     * Take care of resize from end
+     */
+    i = keyframes.begin();
+    lastPos = -1;
+    bool endFound = false;
+    while (i != keyframes.end()) {
+        if (i.key() > out && !endFound) {
+            endFound = true;
+            if (lastPos < 0) {
+                keyframes[out] = i.value();
+            } else {
+                relPos = (out - lastPos) / (qreal)(i.key() - lastPos + 1);
+                keyframes[out] = lastValue + (i.value() - lastValue) * relPos;
+            }
+         }
+        lastPos = i.key();
+        lastValue = i.value();
+        if (endFound)
+            i = keyframes.erase(i);
+        else
+            ++i;
+    }
+
+    if (startFound || endFound) {
+        QString newkfr;
+        QMap<int, double>::const_iterator k = keyframes.constBegin();
+        while (k != keyframes.constEnd()) {
+            newkfr.append(QString::number(k.key()) + ':' + QString::number(qRound(k.value())) + ';');
+            ++k;
+        }
+        parameter.setAttribute("keyframes", newkfr);
+        return true;
+    }
+
+    return false;
+}
+
+void ClipItem::updateGeometryKeyframes(QDomElement effect, int paramIndex, int width, int height, ItemInfo oldInfo)
+{
+    QDomElement param = effect.elementsByTagName("parameter").item(paramIndex).toElement();
+
+    Mlt::Geometry geometry(param.attribute("value").toUtf8().data(), oldInfo.cropDuration.frames(m_fps), width, height);
+
+    param.setAttribute("value", geometry.serialise(cropStart().frames(m_fps), (cropStart() + cropDuration()).frames(m_fps) - 1));
+}
+
 #include "clipitem.moc"
