@@ -36,6 +36,10 @@
 class DocClipBase;
 class Transition;
 
+namespace Mlt
+{
+class Producer;
+};
 
 class ClipItem : public AbstractClipItem
 {
@@ -103,8 +107,9 @@ public:
     void resetThumbs(bool clearExistingThumbs);
 
     /** @brief Updates clip properties from base clip.
-    * @param checkDuration whether or not to check for a valid duration. */
-    void refreshClip(bool checkDuration);
+    * @param checkDuration whether or not to check for a valid duration. 
+    * @param resetThumbs whether or not to recreate the image thumbnails. */
+    void refreshClip(bool checkDuration, bool resetThumbs);
 
     /** @brief Gets clip's marker times.
     * @return A list of the times. */
@@ -151,12 +156,6 @@ public:
     bool isVideoOnly() const;
     bool isAudioOnly() const;
 
-    /** @brief Adjusts the keyframe values to fit a clip resizement.
-    * @param previous Old crop value
-    * @param current New crop value
-    * @param fromStart true = crop from start, false = crop from end
-    * @return true if anything was modified */
-    bool checkEffectsKeyframesPos(const int previous, const int current, bool fromStart);
     void insertKeyframe(QDomElement effect, int pos, int val);
     void movedKeyframe(QDomElement effect, int oldpos, int newpos, double value);
     void updateKeyframes(QDomElement effect);
@@ -168,6 +167,18 @@ public:
      * 
      * Can be used for all effects using mlt_geometry with keyframes, but at the moment Pan & Zoom is the only one. */
     QList <int> updatePanZoom(int width, int height, int cut = 0);
+    void updateGeometryKeyframes(QDomElement effect, int paramIndex, int width, int height, ItemInfo oldInfo);
+    bool updateNormalKeyframes(QDomElement parameter);
+
+    /** @brief Adjusts effects after a clip duration change. */
+    QMap<int, QDomElement> adjustEffectsToDuration(int width, int height, ItemInfo oldInfo);
+
+    /** Returns the necessary (audio, video, general) producer.
+     * @param track Track of the requested producer
+     * @param trackSpecific (default = true) Whether to return general producer for a specific track.
+     * @return Fitting producer
+     * Which producer is returned depends on the type of this clip (audioonly, videoonly, normal) */
+    Mlt::Producer *getProducer(int track, bool trackSpecific = true);
 
 protected:
     //virtual void mouseMoveEvent(QGraphicsSceneMouseEvent * event);
