@@ -25,6 +25,7 @@
 #include "kdenlivedoc.h"
 #include "abstractclipitem.h"
 #include "abstractgroupitem.h"
+#include "titledocument.h"
 
 #include <mlt++/Mlt.h>
 
@@ -39,10 +40,10 @@
 #include <KFileMetaInfo>
 
 ClipManager::ClipManager(KdenliveDoc *doc) :
-        QObject(),
-        m_audioThumbsQueue(),
-        m_doc(doc),
-        m_generatingAudioId()
+    QObject(),
+    m_audioThumbsQueue(),
+    m_doc(doc),
+    m_generatingAudioId()
 {
     m_clipIdCounter = 1;
     m_folderIdCounter = 1;
@@ -55,21 +56,21 @@ ClipManager::ClipManager(KdenliveDoc *doc) :
 
 ClipManager::~ClipManager()
 {
-    qDeleteAll(m_clipList);
-    m_clipList.clear();
     m_audioThumbsQueue.clear();
     m_generatingAudioId.clear();
+    qDeleteAll(m_clipList);
+    m_clipList.clear();
 }
 
 void ClipManager::clear()
 {
+    m_folderList.clear();
+    m_audioThumbsQueue.clear();
+    m_modifiedClips.clear();
     qDeleteAll(m_clipList);
     m_clipList.clear();
     m_clipIdCounter = 1;
     m_folderIdCounter = 1;
-    m_folderList.clear();
-    m_audioThumbsQueue.clear();
-    m_modifiedClips.clear();
 }
 
 void ClipManager::checkAudioThumbs()
@@ -224,22 +225,6 @@ const QList <DocClipBase *> ClipManager::getClipByResource(QString resource)
     return list;
 }
 
-void ClipManager::updatePreviewSettings()
-{
-    for (int i = 0; i < m_clipList.count(); i++) {
-        if (m_clipList.at(i)->clipType() == AV || m_clipList.at(i)->clipType() == VIDEO) {
-            if (m_clipList.at(i)->producerProperty("meta.media.0.codec.name") && strcmp(m_clipList.at(i)->producerProperty("meta.media.0.codec.name"), "h264") == 0) {
-                if (KdenliveSettings::dropbframes()) {
-                    m_clipList[i]->setProducerProperty("skip_loop_filter", "all");
-                    m_clipList[i]->setProducerProperty("skip_frame", "bidir");
-                } else {
-                    m_clipList[i]->setProducerProperty("skip_loop_filter", "");
-                    m_clipList[i]->setProducerProperty("skip_frame", "");
-                }
-            }
-        }
-    }
-}
 
 void ClipManager::clearUnusedProducers()
 {
@@ -272,7 +257,7 @@ void ClipManager::slotAddClipList(const KUrl::List urls, const QString group, co
 {
     QUndoCommand *addClips = new QUndoCommand();
 
-    foreach(const KUrl &file, urls) {
+    foreach(const KUrl & file, urls) {
         if (KIO::NetAccess::exists(file, KIO::NetAccess::SourceSide, NULL)) {
             if (!getClipByResource(file.path()).empty()) {
                 if (KMessageBox::warningContinueCancel(kapp->activeWindow(), i18n("Clip <b>%1</b><br />already exists in project, what do you want to do?", file.path()), i18n("Clip already exists")) == KMessageBox::Cancel)
@@ -293,12 +278,13 @@ void ClipManager::slotAddClipList(const KUrl::List urls, const QString group, co
             if (type->name().startsWith("image/")) {
                 prod.setAttribute("type", (int) IMAGE);
                 prod.setAttribute("in", 0);
-                prod.setAttribute("out", m_doc->getFramePos(KdenliveSettings::image_duration()) - 1);
+                prod.setAttribute("out", m_doc->getFramePos(KdenliveSettings::image_duration()));
+                if (KdenliveSettings::autoimagetransparency()) prod.setAttribute("transparency", 1);
                 // Read EXIF metadata for JPEG
                 if (type->is("image/jpeg")) {
                     KFileMetaInfo metaInfo(file.path(), QString("image/jpeg"), KFileMetaInfo::TechnicalInfo);
                     const QHash<QString, KFileMetaInfoItem> metaInfoItems = metaInfo.items();
-                    foreach(const KFileMetaInfoItem& metaInfoItem, metaInfoItems) {
+                    foreach(const KFileMetaInfoItem & metaInfoItem, metaInfoItems) {
                         prod.setAttribute("meta.attr." + metaInfoItem.name().section("#", 1), metaInfoItem.value().toString());
                     }
                 }
@@ -309,14 +295,28 @@ void ClipManager::slotAddClipList(const KUrl::List urls, const QString group, co
                 if (txtfile.open(QIODevice::ReadOnly) && txtdoc.setContent(&txtfile)) {
                     txtfile.close();
                     prod.setAttribute("type", (int) TEXT);
-                    prod.setAttribute("xmldata", txtdoc.toString());
+                    // extract embeded images
+                    QDomNodeList items = txtdoc.elementsByTagName("content");
+                    for (int i = 0; i < items.count() ; i++) {
+                        QDomElement content = items.item(i).toElement();
+                        if (content.hasAttribute("base64")) {
+                            QString titlesFolder = m_doc->projectFolder().path(KUrl::AddTrailingSlash) + "titles/";
+                            QString path = TitleDocument::extractBase64Image(titlesFolder, content.attribute("base64"));
+                            if (!path.isEmpty()) {
+                                content.setAttribute("url", path);
+                                content.removeAttribute("base64");
+                            }
+                        }
+                    }
+                    QString titleData = txtdoc.toString();
+                    prod.setAttribute("xmldata", titleData);
                     prod.setAttribute("transparency", 1);
                     prod.setAttribute("in", 0);
                     int out = txtdoc.documentElement().attribute("out").toInt();
                     if (out > 0)
                         prod.setAttribute("out", out);
                     else
-                        prod.setAttribute("out", m_doc->getFramePos(KdenliveSettings::title_duration()) - 1);
+                        prod.setAttribute("out", m_doc->getFramePos(KdenliveSettings::title_duration()));
                 } else
                     txtfile.close();
             }
@@ -362,7 +362,7 @@ void ClipManager::slotAddColorClipFile(const QString name, const QString color,
     uint id = m_clipIdCounter++;
     prod.setAttribute("id", QString::number(id));
     prod.setAttribute("in", "0");
-    prod.setAttribute("out", m_doc->getFramePos(duration) - 1);
+    prod.setAttribute("out", m_doc->getFramePos(duration));
     prod.setAttribute("name", name);
     if (!group.isEmpty()) {
         prod.setAttribute("groupname", group);
@@ -373,9 +373,9 @@ void ClipManager::slotAddColorClipFile(const QString name, const QString color,
 }
 
 void ClipManager::slotAddSlideshowClipFile(const QString name, const QString path, int count, const QString duration,
-                                           const bool loop, const bool crop, const bool fade,
-                                           const QString &luma_duration, const QString &luma_file, const int softness,
-                                           const QString &animation, QString group, const QString &groupId)
+        const bool loop, const bool crop, const bool fade,
+        const QString &luma_duration, const QString &luma_file, const int softness,
+        const QString &animation, QString group, const QString &groupId)
 {
     QDomDocument doc;
     QDomElement prod = doc.createElement("producer");
@@ -385,7 +385,7 @@ void ClipManager::slotAddSlideshowClipFile(const QString name, const QString pat
     uint id = m_clipIdCounter++;
     prod.setAttribute("id", QString::number(id));
     prod.setAttribute("in", "0");
-    prod.setAttribute("out", m_doc->getFramePos(duration) * count - 1);
+    prod.setAttribute("out", m_doc->getFramePos(duration) * count);
     prod.setAttribute("ttl", m_doc->getFramePos(duration));
     prod.setAttribute("luma_duration", m_doc->getFramePos(luma_duration));
     prod.setAttribute("name", name);
@@ -452,7 +452,7 @@ void ClipManager::slotAddTextTemplateClip(QString titleName, const KUrl path, co
         out = titledoc.documentElement().attribute("out").toInt();
     } else txtfile.close();
 
-    if (out == 0) out = m_doc->getFramePos(KdenliveSettings::image_duration()) - 1;
+    if (out == 0) out = m_doc->getFramePos(KdenliveSettings::image_duration());
     prod.setAttribute("out", out);
 
     AddClipCommand *command = new AddClipCommand(m_doc, doc.documentElement(), QString::number(id), true);
