@@ -177,7 +177,7 @@ public:
     void clearSelection();
     void editItemDuration();
     void buildGuidesMenu(QMenu *goMenu) const;
-    KPixmapCache* pixmapCache;
+    KPixmapCache* m_pixmapCache;
     /** update the timeline objects when palette changes */
     void updatePalette();
     /** @brief Returns true if a track has audio data on it.
@@ -204,9 +204,17 @@ public slots:
     void slotSwitchTrackVideo(int ix);
     void slotSwitchTrackLock(int ix);
     void slotUpdateClip(const QString &clipId, bool reload = true);
+
+    /** @brief Creates a AddClipCommand to add, edit or delete a marker.
+     * @param id Id of the marker's clip
+     * @param t Position of the marker
+     * @param c Comment of the marker */
     void slotAddClipMarker(const QString &id, GenTime t, QString c);
     bool addGuide(const GenTime pos, const QString &comment);
-    void slotAddGuide();
+
+    /** @brief Shows a dialog for adding a guide.
+     * @param dialog (default = true) false = do not show the dialog but use current position as position and comment */
+    void slotAddGuide(bool dialog = true);
     void slotEditGuide(CommentedTime guide);
     void slotEditGuide(int guidePos = -1);
     void slotDeleteGuide(int guidePos = -1);
@@ -348,7 +356,7 @@ private:
 
     /** Get the index of the video track that is just below current track */
     int getPreviousVideoTrack(int track);
-    void updatePositionEffects(ClipItem * item, ItemInfo info);
+    void updatePositionEffects(ClipItem * item, ItemInfo info, bool standalone = true);
     bool insertDropClips(const QMimeData *data, const QPoint pos);
     bool canBePastedTo(ItemInfo info, int type) const;
     bool canBePastedTo(QList <ItemInfo> infoList, int type) const;
@@ -410,6 +418,28 @@ private:
      * @param cutPos (optional) if clip was cut, cut position relative to the original's clip position */
     void updatePanZoom(ClipItem *item, GenTime cutPos = GenTime());
 
+    /** @brief Update Tracknames to fit again after track was added/deleted.
+     * @param track Number of track which was added/deleted
+     * @param added true = track added, false = track deleted
+     * 
+     * The default track name consists of type + number. If we add/delete a track the number has to be adjusted
+     * if the name is still the default one. */
+    void updateTrackNames(int track, bool added);
+
+    /** @brief Updates the duration stored in a track's TrackInfo.
+     * @param track Number of track as used in ItemInfo (not the numbering used in KdenliveDoc) (negative for all tracks)
+     * @param command If effects need to be updated the commands to do this will be attached to this undo command
+     * 
+     * In addition to update the duration in TrackInfo it updates effects with keyframes on the track. */
+    void updateTrackDuration(int track, QUndoCommand *command);
+
+    /** @brief Adjusts effects after a clip resize.
+     * @param item The item that was resized
+     * @param oldInfo pre resize info
+     * @param fromStart false = resize from end
+     * @param command Used as a parent for EditEffectCommand */
+    void adjustEffects(ClipItem *item, ItemInfo oldInfo, QUndoCommand *command);
+
 private slots:
     void slotRefreshGuides();
     void slotEnableRefresh();
@@ -421,13 +451,21 @@ private slots:
     void slotGoToMarker(QAction *action);
     void slotResetMenuPosition();
     void slotDoResetMenuPosition();
+    /** @brief Re-create the clip thumbnails.
+     *  @param id The clip's Id string.
+     *  @param resetThumbs Should we recreate the timeline thumbnails. */
+    void slotRefreshThumbs(const QString &id, bool resetThumbs);
 
 signals:
     void cursorMoved(int, int);
     void zoomIn();
     void zoomOut();
     void mousePosition(int);
-    void clipItemSelected(ClipItem*, int ix = -1);
+    /** @brief A clip was selected in timeline, update the effect stack
+     *  @param clip The clip
+     *  @param ix The index of currently selected effect
+     *  @param raise If true, the effect stack widget will be raised (come to front). */
+    void clipItemSelected(ClipItem *clip, int ix = -1, bool raise = true);
     void transitionItemSelected(Transition*, int track = 0, QPoint p = QPoint(), bool update = false);
     void activateDocumentMonitor();
     void trackHeightChanged();
