@@ -58,6 +58,8 @@ enum MessageType {
 
 enum TRACKTYPE { AUDIOTRACK = 0, VIDEOTRACK = 1 };
 
+enum PROXYSTATUS { NOPROXY = 0, PROXYWAITING = 1, CREATINGPROXY = 2, PROXYDONE = 3, PROXYCRASHED = 4};
+
 struct TrackInfo {
     TRACKTYPE type;
     QString trackName;
@@ -65,6 +67,7 @@ struct TrackInfo {
     bool isBlind;
     bool isLocked;
     EffectsList effectsList;
+    int duration;
 };
 
 struct ItemInfo {
@@ -91,6 +94,7 @@ struct MltVideoProfile {
     int sample_aspect_den;
     int display_aspect_num;
     int display_aspect_den;
+    int colorspace;
 };
 
 
@@ -149,7 +153,7 @@ class CommentedTime
 public:
     CommentedTime(): t(GenTime(0)) {}
     CommentedTime(const GenTime time, QString comment)
-            : t(time), c(comment) { }
+        : t(time), c(comment) { }
 
     QString comment()   const          {
         return (c.isEmpty() ? i18n("Marker") : c);
