@@ -26,6 +26,8 @@
 #include <QPixmap>
 #include <QObject>
 #include <QTimer>
+#include <QProcess>
+#include <QFuture>
 
 #include <KUrl>
 
@@ -237,6 +239,7 @@ private:   // Private attributes
     QMap <QString, QString> m_properties;
     /** Holds clip metadata like author, copyright,... */
     QMap <QString, QString> m_metadata;
+
     /** Create connections for audio thumbnails */
     void slotCreateAudioTimer();
     void slotRefreshProducer();
@@ -266,6 +269,10 @@ public slots:
 
 signals:
     void gotAudioData();
+    /** @brief Generate a proxy clip (lower resolution copy) named like the clip's hash. */
+    void createProxy(const QString id);
+    /** @brief Abort creation of the proxy clip (lower resolution copy). */
+    void abortProxy(const QString id);
 };
 
 #endif
