@@ -456,7 +456,7 @@ void DvdWizard::generateDvd()
                 QDomText call;
                 if (i == voburls.count() - 1) call = dvddoc.createTextNode("{g1 = 0; call menu;}");
                 else {
-                    call = dvddoc.createTextNode("{if ( g1 eq 999 ) { call menu; } jump title " + QString::number(i + 2) + ";}");
+                    call = dvddoc.createTextNode("{if ( g1 eq 999 ) { call menu; } jump title " + QString::number(i + 2).rightJustified(2, '0') + ";}");
                 }
                 post.appendChild(call);
                 pgc2.appendChild(post);
@@ -485,6 +485,16 @@ void DvdWizard::generateDvd()
     }
     m_creationLog.clear();
     m_dvdauthor = new QProcess(this);
+    // Set VIDEO_FORMAT variable (required by dvdauthor 0.7)
+#if QT_VERSION >= 0x040600
+    QProcessEnvironment env = QProcessEnvironment::systemEnvironment();
+    env.insert("VIDEO_FORMAT", m_pageVob->isPal() ? "PAL" : "NTSC"); 
+    m_dvdauthor->setProcessEnvironment(env);
+#else
+    QStringList env = QProcess::systemEnvironment();
+    env << QString("VIDEO_FORMAT=") + QString(m_pageVob->isPal() ? "PAL" : "NTSC");
+    m_dvdauthor->setEnvironment(env);
+#endif
     connect(m_dvdauthor, SIGNAL(finished(int , QProcess::ExitStatus)), this, SLOT(slotRenderFinished(int, QProcess::ExitStatus)));
     connect(m_dvdauthor, SIGNAL(readyReadStandardOutput()), this, SLOT(slotShowRenderInfo()));
     m_dvdauthor->setProcessChannelMode(QProcess::MergedChannels);
