@@ -122,9 +122,13 @@ QString EffectsList::getInfo(const QString & tag, const QString & id) const
     QString info;
     QDomElement effect = getEffectByTag(tag, id);
     QDomNode namenode = effect.elementsByTagName("description").item(0);
-    if (!namenode.isNull()) info = i18n(namenode.toElement().text().toUtf8().data());
+    if (!namenode.isNull())
+        info = i18n(namenode.firstChild().nodeValue().simplified().toUtf8().data());
+
     namenode = effect.elementsByTagName("author").item(0);
-    if (!namenode.isNull()) info.append("<br /><strong>" + i18n("Author:") + " </strong>" + i18n(namenode.toElement().text().toUtf8().data()));
+    if (!namenode.isNull())
+        info.append("<br /><strong>" + i18n("Author:") + " </strong>" + i18n(namenode.toElement().text().toUtf8().data()));
+
     return info;
 }
 
@@ -161,6 +165,18 @@ bool EffectsList::hasSimpleKeyFrames(QDomElement effect)
     return false;
 }
 
+// static
+bool EffectsList::hasGeometryKeyFrames(QDomElement effect)
+{
+    QDomNodeList params = effect.elementsByTagName("parameter");
+    for (int i = 0; i < params.count(); ++i) {
+        QDomElement param = params.item(i).toElement();
+        if (param.attribute("type") == "geometry" && !param.hasAttribute("fixed"))
+            return true;
+    }
+    return false;
+}
+
 void EffectsList::clone(const EffectsList original)
 {
     setContent(original.toString());
@@ -225,6 +241,19 @@ QString EffectsList::property(QDomElement effect, const QString &name)
     return QString();
 }
 
+// static
+void EffectsList::removeProperty(QDomElement effect, const QString &name)
+{
+    QDomNodeList params = effect.elementsByTagName("property");
+    for (int i = 0; i < params.count(); i++) {
+        QDomElement e = params.item(i).toElement();
+        if (e.attribute("name") == name) {
+            effect.removeChild(params.item(i));
+            break;
+        }
+    }
+}
+
 void EffectsList::append(QDomElement e)
 {
     m_baseElement.appendChild(importNode(e, true));
