@@ -33,10 +33,16 @@
 #include "geometrywidget.h"
 #include "colortools.h"
 #include "doubleparameterwidget.h"
+#include "cornerswidget.h"
+#include "beziercurve/beziersplinewidget.h"
+#ifdef QJSON
+#include "rotoscoping/rotowidget.h"
+#endif
 
 #include <KDebug>
 #include <KLocale>
 #include <KFileDialog>
+#include <KColorScheme>
 
 #include <QVBoxLayout>
 #include <QLabel>
@@ -44,6 +50,9 @@
 #include <QCheckBox>
 #include <QScrollArea>
 
+// For QDomNode debugging (output into files); leaving here as sample code.
+//#define DEBUG_ESE
+
 
 class Boolval: public QWidget, public Ui::Boolval_UI
 {
@@ -64,25 +73,41 @@ class Urlval: public QWidget, public Ui::Urlval_UI
 QMap<QString, QImage> EffectStackEdit::iconCache;
 
 EffectStackEdit::EffectStackEdit(Monitor *monitor, QWidget *parent) :
-        QScrollArea(parent),
-        m_in(0),
-        m_out(0),
-        m_frameSize(QPoint()),
-        m_keyframeEditor(NULL),
-        m_monitor(monitor)
+    QScrollArea(parent),
+    m_in(0),
+    m_out(0),
+    m_frameSize(QPoint()),
+    m_keyframeEditor(NULL),
+    m_monitor(monitor),
+    m_geometryWidget(NULL)
 {
     m_baseWidget = new QWidget(this);
     setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
     setVerticalScrollBarPolicy(Qt::ScrollBarAsNeeded);
     setFrameStyle(QFrame::NoFrame);
     setSizePolicy(QSizePolicy(QSizePolicy::Expanding, QSizePolicy::MinimumExpanding));
-
+    
+    QPalette p = palette();
+    KColorScheme scheme(p.currentColorGroup(), KColorScheme::View, KSharedConfig::openConfig(KdenliveSettings::colortheme()));
+    QColor dark_bg = scheme.shade(KColorScheme::DarkShade);
+    QColor selected_bg = scheme.decoration(KColorScheme::FocusColor).color();
+    QColor hover_bg = scheme.decoration(KColorScheme::HoverColor).color();    
+    QColor light_bg = scheme.shade(KColorScheme::LightShade);
+    
+    QString stylesheet(QString("QProgressBar:horizontal {border: 1px solid %1;border-radius:0px;border-top-left-radius: 4px;border-bottom-left-radius: 4px;border-right: 0px;background:%4;padding: 0px;text-align:left center}\
+                                QProgressBar:horizontal#dragOnly {background: %1} QProgressBar:horizontal:hover#dragOnly {background: %3} QProgressBar:horizontal:hover {border: 1px solid %3;border-right: 0px;}\
+                                QProgressBar::chunk:horizontal {background: %1;} QProgressBar::chunk:horizontal:hover {background: %3;}\
+                                QProgressBar:horizontal[inTimeline=\"true\"] { border: 1px solid %2;border-right: 0px;background: %4;padding: 0px;text-align:left center } QProgressBar::chunk:horizontal[inTimeline=\"true\"] {background: %2;}\
+                                QAbstractSpinBox#dragBox {border: 1px solid %1;border-top-right-radius: 4px;border-bottom-right-radius: 4px;padding-right:0px;} QAbstractSpinBox::down-button#dragBox {width:0px;padding:0px;}\
+                                QAbstractSpinBox::up-button#dragBox {width:0px;padding:0px;} QAbstractSpinBox[inTimeline=\"true\"]#dragBox { border: 1px solid %2;} QAbstractSpinBox:hover#dragBox {border: 1px solid %3;} ")
+                                .arg(dark_bg.name()).arg(selected_bg.name()).arg(hover_bg.name()).arg(light_bg.name()));
+    setStyleSheet(stylesheet);
+    
     setWidget(m_baseWidget);
     setWidgetResizable(true);
     m_vbox = new QVBoxLayout(m_baseWidget);
     m_vbox->setContentsMargins(0, 0, 0, 0);
-    m_vbox->setSpacing(0);
-    //wid->show();
+    m_vbox->setSpacing(2);
 }
 
 EffectStackEdit::~EffectStackEdit()
@@ -101,10 +126,16 @@ void EffectStackEdit::setFrameSize(QPoint p)
         QString type = pa.attributes().namedItem("type").nodeValue();
         QString paramName = i18n(na.toElement().text().toUtf8().data());
 
-        if (type == "geometry" && !KdenliveSettings::on_monitor_effects()) {
-            Geometryval *geom = ((Geometryval*)m_valueItems[paramName+"geometry"]);
-            geom->setFrameSize(m_frameSize);
-            break;
+        if (type == "geometry") {
+            if (!KdenliveSettings::on_monitor_effects()) {
+                Geometryval *geom = ((Geometryval*)m_valueItems[paramName+"geometry"]);
+                geom->setFrameSize(m_frameSize);
+                break;
+            }
+            else {
+                if (m_geometryWidget) m_geometryWidget->setFrameSize(m_frameSize);
+                break;
+            }
         }
     }
 }
@@ -123,18 +154,19 @@ void EffectStackEdit::updateTimecodeFormat()
 
         if (type == "geometry") {
             if (KdenliveSettings::on_monitor_effects()) {
-                GeometryWidget *geom = (GeometryWidget*)m_valueItems[paramName+"geometry"];
-                geom->updateTimecodeFormat();
+                if (m_geometryWidget) m_geometryWidget->updateTimecodeFormat();
             } else {
                 Geometryval *geom = ((Geometryval*)m_valueItems[paramName+"geometry"]);
                 geom->updateTimecodeFormat();
             }
             break;
-        }
-        if (type == "position") {
+        } else if (type == "position") {
             PositionEdit *posi = ((PositionEdit*)m_valueItems[paramName+"position"]);
             posi->updateTimecodeFormat();
             break;
+        } else if (type == "roto-spline") {
+            RotoWidget *widget = static_cast<RotoWidget *>(m_valueItems[paramName]);
+            widget->updateTimecodeFormat();
         }
     }
 }
@@ -145,7 +177,12 @@ void EffectStackEdit::meetDependency(const QString& name, QString type, QString
         KisCurveWidget *curve = (KisCurveWidget*)m_valueItems[name];
         if (curve) {
             int color = value.toInt();
-            curve->setPixmap(QPixmap::fromImage(ColorTools::rgbCurvePlane(curve->size(), (ColorTools::ColorsRGB)color, 0.8)));
+            curve->setPixmap(QPixmap::fromImage(ColorTools::rgbCurvePlane(curve->size(), (ColorTools::ColorsRGB)(color == 3 ? 4 : color), 0.8)));
+        }
+    } else if (type == "bezier_spline") {
+        BezierSplineWidget *widget = (BezierSplineWidget*)m_valueItems[name];
+        if (widget) {
+            widget->setMode((BezierSplineWidget::CurveModes)((int)(value.toDouble() * 10)));
         }
     }
 }
@@ -159,6 +196,13 @@ void EffectStackEdit::updateProjectFormat(MltVideoProfile profile, Timecode t)
 void EffectStackEdit::updateParameter(const QString &name, const QString &value)
 {
     m_params.setAttribute(name, value);
+
+    if (name == "disable") {
+        // if effect is disabled, disable parameters widget
+        bool enabled = value.toInt() == 0 || !KdenliveSettings::disable_effect_parameters();
+        setEnabled(enabled);
+        emit effectStateChanged(enabled);
+    }
 }
 
 void EffectStackEdit::transferParamDesc(const QDomElement d, int pos, int in, int out, bool isEffect)
@@ -170,37 +214,49 @@ void EffectStackEdit::transferParamDesc(const QDomElement d, int pos, int in, in
     m_in = in;
     m_out = out;
     if (m_params.isNull()) {
-        kDebug() << "// EMPTY EFFECT STACK";
+//         kDebug() << "// EMPTY EFFECT STACK";
         return;
     }
 
     QDomNodeList namenode = m_params.elementsByTagName("parameter");
+#ifdef DEBUG_ESE
+    QFile debugFile("/tmp/namenodes.txt");
+    if (debugFile.open(QFile::WriteOnly | QFile::Truncate)) {
+        QTextStream out(&debugFile);
+        QTextStream out2(stdout);
+        for (int i = 0; i < namenode.size(); i++) {
+            out << i << ": \n";
+            namenode.at(i).save(out, 2);
+            out2 << i << ": \n";
+            namenode.at(i).save(out2, 2);
+        }
+    }
+#endif
     QDomElement e = m_params.toElement();
     const int minFrame = e.attribute("start").toInt();
     const int maxFrame = e.attribute("end").toInt();
 
+    bool disable = d.attribute("disable") == "1" && KdenliveSettings::disable_effect_parameters();
+    setEnabled(!disable);
+
+    bool stretch = true;
+
 
     for (int i = 0; i < namenode.count() ; i++) {
         QDomElement pa = namenode.item(i).toElement();
-        QDomNode na = pa.firstChildElement("name");
+        QDomElement na = pa.firstChildElement("name");
+        QDomElement commentElem = pa.firstChildElement("comment");
         QString type = pa.attribute("type");
-        QString paramName = i18n(na.toElement().text().toUtf8().data());
+        QString paramName = i18n(na.text().toUtf8().data());
+        QString comment;
+        if (!commentElem.isNull())
+            comment = i18n(commentElem.text().toUtf8().data());
         QWidget * toFillin = new QWidget(m_baseWidget);
         QString value = pa.attribute("value").isNull() ?
                         pa.attribute("default") : pa.attribute("value");
 
-        /** Currently supported parameter types are:
-            * constant (=double): a slider with an integer value (use the "factor" attribute to divide the value so that you can get a double
-            * list: a combobox containing a list of values to choose
-            * bool: a checkbox
-            * complex: designed for keyframe parameters, but old and not finished, do not use
-            * geometry: a rectangle that can be moved & resized, with possible keyframes, used in composite transition
-            * keyframe: a list widget with a list of entries (position and value)
-            * color: a color chooser button
-            * position: a slider representing the position of a frame in the current clip
-            * curve: a single curve representing multiple points
-            * wipe: a widget designed for the wipe transition, allowing to choose a position (left, right, top,...)
-        */
+
+        /** See effects/README for info on the different types */
 
         if (type == "double" || type == "constant") {
             int min;
@@ -215,17 +271,21 @@ void EffectStackEdit::transferParamDesc(const QDomElement d, int pos, int in, in
                 max = pa.attribute("max").toInt();
 
             DoubleParameterWidget *doubleparam = new DoubleParameterWidget(paramName, (int)(value.toDouble() + 0.5), min, max,
-                    pa.attribute("default").toInt(), pa.attribute("suffix"), this);
+                    pa.attribute("default").toInt(), comment, -1, pa.attribute("suffix"), this);
             m_vbox->addWidget(doubleparam);
             m_valueItems[paramName] = doubleparam;
             connect(doubleparam, SIGNAL(valueChanged(int)), this, SLOT(collectAllParameters()));
+            connect(this, SIGNAL(showComments(bool)), doubleparam, SLOT(slotShowComment(bool)));
         } else if (type == "list") {
             Listval *lsval = new Listval;
             lsval->setupUi(toFillin);
             QStringList listitems = pa.attribute("paramlist").split(',');
-            QStringList listitemsdisplay = pa.attribute("paramlistdisplay").split(',');
-            if (listitemsdisplay.count() != listitems.count()) listitemsdisplay = listitems;
-            //lsval->list->addItems(listitems);
+            QDomElement list = pa.firstChildElement("paramlistdisplay");
+            QStringList listitemsdisplay;
+            if (!list.isNull()) listitemsdisplay = i18n(list.text().toUtf8().data()).split(',');
+            else listitemsdisplay = i18n(pa.attribute("paramlistdisplay").toUtf8().data()).split(',');
+            if (listitemsdisplay.count() != listitems.count())
+                listitemsdisplay = listitems;
             lsval->list->setIconSize(QSize(30, 30));
             for (int i = 0; i < listitems.count(); i++) {
                 lsval->list->addItem(listitemsdisplay.at(i), listitems.at(i));
@@ -239,17 +299,25 @@ void EffectStackEdit::transferParamDesc(const QDomElement d, int pos, int in, in
                 }
             }
             if (!value.isEmpty()) lsval->list->setCurrentIndex(listitems.indexOf(value));
-            lsval->title->setTitle(paramName);
+            lsval->name->setText(paramName);
+            lsval->labelComment->setText(comment);
+            lsval->widgetComment->setHidden(true);
             m_valueItems[paramName] = lsval;
             connect(lsval->list, SIGNAL(currentIndexChanged(int)) , this, SLOT(collectAllParameters()));
+            if (!comment.isEmpty())
+                connect(this, SIGNAL(showComments(bool)), lsval->widgetComment, SLOT(setVisible(bool)));
             m_uiItems.append(lsval);
         } else if (type == "bool") {
             Boolval *bval = new Boolval;
             bval->setupUi(toFillin);
             bval->checkBox->setCheckState(value == "0" ? Qt::Unchecked : Qt::Checked);
-            bval->checkBox->setText(paramName);
+            bval->name->setText(paramName);
+            bval->labelComment->setText(comment);
+            bval->widgetComment->setHidden(true);
             m_valueItems[paramName] = bval;
             connect(bval->checkBox, SIGNAL(stateChanged(int)) , this, SLOT(collectAllParameters()));
+            if (!comment.isEmpty())
+                connect(this, SIGNAL(showComments(bool)), bval->widgetComment, SLOT(setVisible(bool)));
             m_uiItems.append(bval);
         } else if (type == "complex") {
             ComplexParameter *pl = new ComplexParameter;
@@ -259,18 +327,21 @@ void EffectStackEdit::transferParamDesc(const QDomElement d, int pos, int in, in
             connect(pl, SIGNAL(parameterChanged()), this, SLOT(collectAllParameters()));
         } else if (type == "geometry") {
             if (KdenliveSettings::on_monitor_effects()) {
-                GeometryWidget *geometry = new GeometryWidget(m_monitor, m_timecode, pos, isEffect, this);
+                m_geometryWidget = new GeometryWidget(m_monitor, m_timecode, pos, isEffect, m_params.hasAttribute("showrotation"), this);
+                m_geometryWidget->setFrameSize(m_frameSize);
+                m_geometryWidget->slotShowScene(!disable);
                 // connect this before setupParam to make sure the monitor scene shows up at startup
-                connect(geometry, SIGNAL(checkMonitorPosition(int)), this, SIGNAL(checkMonitorPosition(int)));
-                connect(geometry, SIGNAL(parameterChanged()), this, SLOT(collectAllParameters()));
+                connect(m_geometryWidget, SIGNAL(checkMonitorPosition(int)), this, SIGNAL(checkMonitorPosition(int)));
+                connect(m_geometryWidget, SIGNAL(parameterChanged()), this, SLOT(collectAllParameters()));
                 if (minFrame == maxFrame)
-                    geometry->setupParam(pa, m_in, m_out);
+                    m_geometryWidget->setupParam(pa, m_in, m_out);
                 else
-                    geometry->setupParam(pa, minFrame, maxFrame);
-                m_vbox->addWidget(geometry);
-                m_valueItems[paramName+"geometry"] = geometry;
-                connect(geometry, SIGNAL(seekToPos(int)), this, SIGNAL(seekTimeline(int)));
-                connect(this, SIGNAL(syncEffectsPos(int)), geometry, SLOT(slotSyncPosition(int)));
+                    m_geometryWidget->setupParam(pa, minFrame, maxFrame);
+                m_vbox->addWidget(m_geometryWidget);
+                m_valueItems[paramName+"geometry"] = m_geometryWidget;
+                connect(m_geometryWidget, SIGNAL(seekToPos(int)), this, SIGNAL(seekTimeline(int)));
+                connect(this, SIGNAL(syncEffectsPos(int)), m_geometryWidget, SLOT(slotSyncPosition(int)));
+                connect(this, SIGNAL(effectStateChanged(bool)), m_geometryWidget, SLOT(slotShowScene(bool)));
             } else {
                 Geometryval *geo = new Geometryval(m_profile, m_timecode, m_frameSize, pos);
                 if (minFrame == maxFrame)
@@ -283,16 +354,30 @@ void EffectStackEdit::transferParamDesc(const QDomElement d, int pos, int in, in
                 connect(geo, SIGNAL(seekToPos(int)), this, SIGNAL(seekTimeline(int)));
                 connect(this, SIGNAL(syncEffectsPos(int)), geo, SLOT(slotSyncPosition(int)));
             }
+        } else if (type == "addedgeometry") {
+            // this is a parameter that should be linked to the geometry widget, for example rotation, shear, ...
+            if (m_geometryWidget) m_geometryWidget->addParameter(pa);
         } else if (type == "keyframe" || type == "simplekeyframe") {
-            // keyframe editor widget
-            kDebug() << "min: " << m_in << ", MAX: " << m_out;
+            // keyframe editor widget
             if (m_keyframeEditor == NULL) {
-                KeyframeEdit *geo = new KeyframeEdit(pa, m_in, m_in + m_out, pa.attribute("min").toInt(), pa.attribute("max").toInt(), m_timecode, e.attribute("active_keyframe", "-1").toInt());
+                KeyframeEdit *geo;
+                if (pa.attribute("widget") == "corners") {
+                    // we want a corners-keyframe-widget
+                    CornersWidget *corners = new CornersWidget(m_monitor, pa, m_in, m_out, m_timecode, e.attribute("active_keyframe", "-1").toInt(), this);
+                    corners->slotShowScene(!disable);
+                    connect(corners, SIGNAL(checkMonitorPosition(int)), this, SIGNAL(checkMonitorPosition(int)));
+                    connect(this, SIGNAL(effectStateChanged(bool)), corners, SLOT(slotShowScene(bool)));
+                    connect(this, SIGNAL(syncEffectsPos(int)), corners, SLOT(slotSyncPosition(int)));
+                    geo = static_cast<KeyframeEdit *>(corners);
+                } else {
+                    geo = new KeyframeEdit(pa, m_in, m_out, m_timecode, e.attribute("active_keyframe", "-1").toInt());
+                }
                 m_vbox->addWidget(geo);
                 m_valueItems[paramName+"keyframe"] = geo;
                 m_keyframeEditor = geo;
                 connect(geo, SIGNAL(parameterChanged()), this, SLOT(collectAllParameters()));
                 connect(geo, SIGNAL(seekToPos(int)), this, SIGNAL(seekTimeline(int)));
+                connect(this, SIGNAL(showComments(bool)), geo, SIGNAL(showComments(bool)));
             } else {
                 // we already have a keyframe editor, so just add another column for the new param
                 m_keyframeEditor->addParameter(pa);
@@ -350,6 +435,27 @@ void EffectStackEdit::transferParamDesc(const QDomElement d, int pos, int in, in
             QString depends = pa.attribute("depends");
             if (!depends.isEmpty())
                 meetDependency(paramName, type, EffectsList::parameter(e, depends));
+        } else if (type == "bezier_spline") {
+            BezierSplineWidget *widget = new BezierSplineWidget(value, this);
+            stretch = false;
+            m_vbox->addWidget(widget);
+            m_valueItems[paramName] = widget;
+            connect(widget, SIGNAL(modified()), this, SLOT(collectAllParameters()));
+            QString depends = pa.attribute("depends");
+            if (!depends.isEmpty())
+                meetDependency(paramName, type, EffectsList::parameter(e, depends));
+#ifdef QJSON
+        } else if (type == "roto-spline") {
+            RotoWidget *roto = new RotoWidget(value, m_monitor, m_in, m_out, m_timecode, this);
+            roto->slotShowScene(!disable);
+            connect(roto, SIGNAL(valueChanged()), this, SLOT(collectAllParameters()));
+            connect(roto, SIGNAL(checkMonitorPosition(int)), this, SIGNAL(checkMonitorPosition(int)));
+            connect(roto, SIGNAL(seekToPos(int)), this, SIGNAL(seekTimeline(int)));
+            connect(this, SIGNAL(syncEffectsPos(int)), roto, SLOT(slotSyncPosition(int)));
+            connect(this, SIGNAL(effectStateChanged(bool)), roto, SLOT(slotShowScene(bool)));
+            m_vbox->addWidget(roto);
+            m_valueItems[paramName] = roto;
+#endif
         } else if (type == "wipe") {
             Wipeval *wpval = new Wipeval;
             wpval->setupUi(toFillin);
@@ -423,7 +529,22 @@ void EffectStackEdit::transferParamDesc(const QDomElement d, int pos, int in, in
         if (toFillin)
             m_vbox->addWidget(toFillin);
     }
-    m_vbox->addStretch();
+
+    if (stretch)
+        m_vbox->addStretch();
+
+    if (m_keyframeEditor)
+        m_keyframeEditor->checkVisibleParam();
+    
+    // Make sure all doubleparam spinboxes have the same width, looks much better
+    QList<DoubleParameterWidget *> allWidgets = findChildren<DoubleParameterWidget *>();
+    int minSize = 0;
+    for (int i = 0; i < allWidgets.count(); i++) {
+        if (minSize < allWidgets.at(i)->spinSize()) minSize = allWidgets.at(i)->spinSize();
+    }
+    for (int i = 0; i < allWidgets.count(); i++) {
+        allWidgets.at(i)->setSpinSize(minSize);
+    }
 }
 
 wipeInfo EffectStackEdit::getWipeInfo(QString value)
@@ -532,7 +653,7 @@ void EffectStackEdit::collectAllParameters()
             paramName.append("geometry");
         else if (type == "keyframe")
             paramName.append("keyframe");
-        if (type != "simplekeyframe" && !m_valueItems.contains(paramName)) {
+        if (type != "simplekeyframe" && type != "fixed" && type != "addedgeometry" && !m_valueItems.contains(paramName)) {
             kDebug() << "// Param: " << paramName << " NOT FOUND";
             continue;
         }
@@ -555,12 +676,13 @@ void EffectStackEdit::collectAllParameters()
             namenode.item(i) = complex->getParamDesc();
         } else if (type == "geometry") {
             if (KdenliveSettings::on_monitor_effects()) {
-                GeometryWidget *geometry = ((GeometryWidget*)m_valueItems.value(paramName));
-                namenode.item(i).toElement().setAttribute("value", geometry->getValue());
+                if (m_geometryWidget) namenode.item(i).toElement().setAttribute("value", m_geometryWidget->getValue());
             } else {
                 Geometryval *geom = ((Geometryval*)m_valueItems.value(paramName));
                 namenode.item(i).toElement().setAttribute("value", geom->getValue());
             }
+        } else if (type == "addedgeometry") {
+            namenode.item(i).toElement().setAttribute("value", m_geometryWidget->getExtraValue(namenode.item(i).toElement().attribute("name")));
         } else if (type == "position") {
             PositionEdit *pedit = ((PositionEdit*)m_valueItems.value(paramName));
             int pos = pedit->getPosition();
@@ -604,6 +726,17 @@ void EffectStackEdit::collectAllParameters()
             QString depends = pa.attributes().namedItem("depends").nodeValue();
             if (!depends.isEmpty())
                 meetDependency(paramName, type, EffectsList::parameter(newparam, depends));
+        } else if (type == "bezier_spline") {
+            BezierSplineWidget *widget = (BezierSplineWidget*)m_valueItems.value(paramName);
+            setValue = widget->spline();
+            QString depends = pa.attributes().namedItem("depends").nodeValue();
+            if (!depends.isEmpty())
+                meetDependency(paramName, type, EffectsList::parameter(newparam, depends));
+#ifdef QJSON
+        } else if (type == "roto-spline") {
+            RotoWidget *widget = static_cast<RotoWidget *>(m_valueItems.value(paramName));
+            setValue = widget->getSpline();
+#endif
         } else if (type == "wipe") {
             Wipeval *wp = (Wipeval*)m_valueItems.value(paramName);
             wipeInfo info;
@@ -637,10 +770,15 @@ void EffectStackEdit::collectAllParameters()
 
             setValue = getWipeString(info);
         } else if ((type == "simplekeyframe" || type == "keyframe") && m_keyframeEditor) {
+            QDomElement elem = pa.toElement();
             QString realName = i18n(na.toElement().text().toUtf8().data());
             QString val = m_keyframeEditor->getValue(realName);
-            //kDebug() << "SET VALUE: " << val;
-            namenode.item(i).toElement().setAttribute("keyframes", val);
+            elem.setAttribute("keyframes", val);
+
+            if (m_keyframeEditor->isVisibleParam(realName))
+                elem.setAttribute("intimeline", "1");
+            else if (elem.hasAttribute("intimeline"))
+                elem.removeAttribute("intimeline");
         } else if (type == "url") {
             KUrlRequester *req = ((Urlval*)m_valueItems.value(paramName))->urlwidget;
             setValue = req->url().path();
@@ -671,6 +809,7 @@ void EffectStackEdit::clearAllItems()
         if (wid) delete wid;
     }
     m_keyframeEditor = NULL;
+    m_geometryWidget = NULL;
     blockSignals(false);
 }
 
