@@ -40,6 +40,7 @@ struct wipeInfo {
 
 class QFrame;
 class Monitor;
+class GeometryWidget;
 
 class EffectStackEdit : public QScrollArea
 {
@@ -49,7 +50,7 @@ public:
     ~EffectStackEdit();
     void updateProjectFormat(MltVideoProfile profile, Timecode t);
     static QMap<QString, QImage> iconCache;
-    /** @brief Sets attribute @param name to @param value. 
+    /** @brief Sets attribute @param name to @param value.
     *
     * Used to disable the effect, by setting disabled="1" */
     void updateParameter(const QString &name, const QString &value);
@@ -80,14 +81,17 @@ private:
     QPoint m_frameSize;
     KeyframeEdit *m_keyframeEditor;
     Monitor *m_monitor;
+    GeometryWidget *m_geometryWidget;
 
 public slots:
     /** @brief Called when an effect is selected, builds the UI for this effect. */
     void transferParamDesc(const QDomElement d, int pos, int in, int out, bool isEffect = true);
+
     /** @brief Called whenever(?) some parameter is changed in the gui.
      *
      * Transfers all Dynamic gui parameter settings into m_params(??) */
     void collectAllParameters();
+
     /** @brief Pass position changes of the timeline cursor to the effects to keep their local timelines in sync. */
     void slotSyncEffectsPos(int pos);
 
@@ -97,6 +101,8 @@ signals:
     void displayMessage(const QString&, int);
     void checkMonitorPosition(int);
     void syncEffectsPos(int pos);
+    void showComments(bool show);
+    void effectStateChanged(bool enabled);
 };
 
 #endif
