@@ -74,6 +74,9 @@ private:
     /** @brief The track index of currently edited track. */
     int m_trackindex;
 
+    /** If in track mode: Info of the edited track to be able to access its duration. */
+    TrackInfo m_trackInfo;
+
     /** @brief Sets the list of effects according to the clip's effect list.
     * @param ix Number of the effect to preselect */
     void setupListView(int ix);
@@ -136,6 +139,9 @@ private slots:
     /** @brief Pass position changes of the timeline cursor to the effects to keep their local timelines in sync. */
     void slotRenderPos(int pos);
 
+    /** @brief Shows/Hides the comment box and emits showComments to notify the parameter widgets to do the same. */
+    void slotShowComments();
+
 signals:
     void removeEffect(ClipItem*, int, QDomElement);
     /**  Parameters for an effect changed, update the filter in playlist */
@@ -154,6 +160,7 @@ signals:
     /** The region effect for current effect was changed */
     void updateClipRegion(ClipItem*, int, QString);
     void displayMessage(const QString&, int);
+    void showComments(bool show);
 };
 
 #endif
