@@ -45,11 +45,14 @@ class DocClipBase;
 class MainWindow;
 class TrackInfo;
 
+class KTextEdit;
+class KProgressDialog;
+
 class KdenliveDoc: public QObject
 {
 Q_OBJECT public:
 
-    KdenliveDoc(const KUrl &url, const KUrl &projectFolder, QUndoGroup *undoGroup, QString profileName, const QPoint tracks, Render *render, MainWindow *parent = 0);
+    KdenliveDoc(const KUrl &url, const KUrl &projectFolder, QUndoGroup *undoGroup, QString profileName, QMap <QString, QString> properties, const QPoint tracks, Render *render, KTextEdit *notes, MainWindow *parent = 0, KProgressDialog *progressDialog = 0);
     ~KdenliveDoc();
     QDomNodeList producersList();
     double fps() const;
@@ -107,27 +110,40 @@ Q_OBJECT public:
     void syncGuides(QList <Guide *> guides);
     void setZoom(int horizontal, int vertical);
     QPoint zoom() const;
-    double dar();
+    double dar() const;
     double projectDuration() const;
-    bool saveSceneList(const QString &path, const QString &scene);
+    bool saveSceneList(const QString &path, const QString &scene, const QStringList expandedFolders);
     int tracksCount() const;
     TrackInfo trackInfoAt(int ix) const;
     void insertTrack(int ix, TrackInfo type);
     void deleteTrack(int ix);
     void setTrackType(int ix, TrackInfo type);
     const QList <TrackInfo> tracksList() const;
+
+    /** @brief Gets the number of audio and video tracks and returns them as a QPoint with x = video, y = audio. */
     QPoint getTracksCount() const;
+
     void switchTrackVideo(int ix, bool hide);
     void switchTrackAudio(int ix, bool hide);
     void switchTrackLock(int ix, bool lock);
+    bool isTrackLocked(int ix) const;
+
+    /** @brief Sets the duration of track @param ix to @param duration.
+     * This does not! influence the actual track but only the value in its TrackInfo. */
+    void setTrackDuration(int ix, int duration);
+
+    /** @brief Returns the duration of track @param ix.
+     *
+     * The returned duration might differ from the actual track duration!
+     * It is the one stored in the track's TrackInfo. */
+    int trackDuration(int ix);
+
     void cachePixmap(const QString &fileId, const QPixmap &pix) const;
     void setProjectFolder(KUrl url);
     QString getLadspaFile() const;
     void setZone(int start, int end);
     QPoint zone() const;
     int setSceneList();
-    void updatePreviewSettings();
-    bool isTrackLocked(int ix) const;
     void setDocumentProperty(const QString &name, const QString &value);
     const QString getDocumentProperty(const QString &name) const;
 
@@ -138,7 +154,9 @@ Q_OBJECT public:
     void setTrackEffect(int trackIndex, int effectIndex, QDomElement effect);
     const EffectsList getTrackEffects(int ix);
     QDomElement getTrackEffect(int trackIndex, int effectIndex) const;
-
+    /** @brief Get a list of folder id's that were opened on last save. */
+    QStringList getExpandedFolders();
+    
 private:
     KUrl m_url;
     QDomDocument m_document;
@@ -147,6 +165,7 @@ private:
     int m_height;
     Timecode m_timecode;
     Render *m_render;
+    KTextEdit *m_notesWidget;
     QUndoStack *m_commandStack;
     ClipManager *m_clipManager;
     MltVideoProfile m_profile;
@@ -169,6 +188,12 @@ private:
     /** @brief Creates a new project. */
     QDomDocument createEmptyDocument(int videotracks, int audiotracks);
     QDomDocument createEmptyDocument(QList <TrackInfo> tracks);
+    /** @brief Saves effects embedded in project file.
+    *   @return True if effects were imported.  */
+    bool saveCustomEffects(QDomNodeList customeffects);
+
+    /** @brief Updates the project folder location entry in the kdenlive file dialogs to point to the current project folder. */
+    void updateProjectFolderPlacesEntry();
 
 public slots:
     void slotCreateXmlClip(const QString &name, const QDomElement xml, QString group, const QString &groupId);
