@@ -20,8 +20,6 @@
 
 #include <QPixmap>
 #include <QFile>
-#include <QThread>
-#include <QMutex>
 #include <QDomElement>
 #include <QFuture>
 
@@ -50,32 +48,6 @@ class Profile;
 
 class ClipManager;
 
-
-
-class MyThread : public QThread
-{
-    Q_OBJECT
-public:
-    virtual void run();
-    void init(KUrl url, QString target, double frame, double frameLength, int frequency, int channels, int arrayWidth);
-    bool isWorking();
-    bool stop_me;
-
-private:
-    QFile f;
-    KUrl m_url;
-    double m_frame;
-    double m_frameLength;
-    int m_frequency;
-    int m_channels;
-    int m_arrayWidth;
-    bool m_isWorking;
-
-signals:
-    void audioThumbProgress(const int);
-    void audioThumbOver();
-};
-
 class KThumb: public QObject
 {
 Q_OBJECT public:
@@ -102,13 +74,17 @@ public slots:
     void getAudioThumbs(int channel, double frame, double frameLength, int arrayWidth);
     static QPixmap getImage(KUrl url, int frame, int width, int height);
     static QImage getFrame(Mlt::Producer *producer, int framepos, int width, int height);
+    /** @brief Calculates image variance, useful to know if a thumbnail is interesting. 
+     *  @return an integer between 0 and 100. 0 means no variance, eg. black image while bigger values mean contrasted image
+     * */
+    static uint imageVariance(QImage image);
 
 private slots:
-    void slotAudioThumbProgress(const int progress);
     void slotAudioThumbOver();
+    void slotCreateAudioThumbs();
 
 private:
-    MyThread m_audioThumbProducer;
+    QFuture<void> m_audioThumbProducer;
     KUrl m_url;
     QString m_thumbFile;
     double m_dar;
@@ -117,6 +93,13 @@ private:
     QString m_id;
     QList <int> m_requestedThumbs;
     QFuture<void> m_future;
+    QFile m_audioThumbFile;
+    bool m_stopAudioThumbs;
+    double m_frame;
+    double m_frameLength;
+    int m_frequency;
+    int m_channels;
+    int m_arrayWidth;
     void doGetThumbs();
 
 signals:
