@@ -37,12 +37,14 @@
 #include <KRecentFilesAction>
 #include <KComboBox>
 #include <kautosavefile.h>
+#include <KActionCategory>
 
 #include "effectslist.h"
 #include "gentime.h"
 #include "definitions.h"
 #include "statusbarmessagelabel.h"
 #include "dvdwizard.h"
+#include "stopmotion/stopmotion.h"
 
 class KdenliveDoc;
 class TrackView;
@@ -57,6 +59,7 @@ class CustomTrackView;
 class RenderWidget;
 #ifndef NO_JOGSHUTTLE
 class JogShuttle;
+class JogShuttleAction;
 #endif /* NO_JOGSHUTTLE */
 class DocClipBase;
 class Render;
@@ -66,7 +69,10 @@ class Vectorscope;
 class Waveform;
 class RGBParade;
 class KActionCollection;
-
+class AudioSignal;
+class AbstractAudioScopeWidget;
+class AudioSpectrum;
+class Spectrogram;
 
 class MainWindow : public KXmlGuiWindow
 {
@@ -78,12 +84,13 @@ public:
     /** @brief Initialises the main window.
      * @param MltPath (optional) path to MLT environment
      * @param Url (optional) file to open
+     * @param clipsToLoad (optional) a comma separated list of clips to import in project
      *
      * If Url is present, it will be opened, otherwhise, if openlastproject is
      * set, latest project will be opened. If no file is open after trying this,
      * a default new file will be created. */
     explicit MainWindow(const QString &MltPath = QString(),
-                        const KUrl &Url = KUrl(), QWidget *parent = 0);
+                        const KUrl &Url = KUrl(), const QString & clipsToLoad = QString(), QWidget *parent = 0);
     virtual ~MainWindow();
 
     /** @brief Locates the MLT environment.
@@ -141,6 +148,9 @@ private:
     EffectsListView *m_effectList;
     //KListWidget *m_effectList;
 
+    QDockWidget *m_notesDock;
+    KTextEdit *m_notesWidget;
+
     QDockWidget *m_effectStackDock;
     EffectStackView *m_effectStack;
 
@@ -168,6 +178,15 @@ private:
     QDockWidget *m_histogramDock;
     Histogram *m_histogram;
 
+    QDockWidget *m_audiosignalDock;
+    AudioSignal *m_audiosignal;
+
+    QDockWidget *m_audioSpectrumDock;
+    AudioSpectrum *m_audioSpectrum;
+
+    QDockWidget *m_spectrogramDock;
+    Spectrogram *m_spectrogram;
+
     QDockWidget *m_undoViewDock;
     QUndoView *m_undoView;
     QUndoGroup *m_commandStack;
@@ -175,17 +194,24 @@ private:
     KComboBox *m_timecodeFormat;
 
     /** This list holds all the scopes used in Kdenlive, allowing to manage some global settings */
-    QList <QDockWidget *> m_scopesList;
+    QList <QDockWidget *> m_gfxScopesList;
+    QList <AbstractAudioScopeWidget *> m_audioScopesList;
 
-    QMenu *m_videoEffectsMenu;
-    QMenu *m_audioEffectsMenu;
-    QMenu *m_customEffectsMenu;
+    KActionCategory *m_effectActions;
+    QMenu *m_effectsMenu;
     QMenu *m_transitionsMenu;
     QMenu *m_timelineContextMenu;
     QMenu *m_timelineContextClipMenu;
     QMenu *m_timelineContextTransitionMenu;
     KUrl m_startUrl;
 
+    /** Actions used in the stopmotion widget */
+    KActionCategory *m_stopmotion_actions;
+    
+    /** Action names that can be used in the slotDoAction() slot, with their i18n() names */
+    QStringList m_action_names;
+
+
     /** @brief Shortcut to remove the focus from any element.
      *
      * It allows to get out of e.g. text input fields and to press another
@@ -196,6 +222,7 @@ private:
 
 #ifndef NO_JOGSHUTTLE
     JogShuttle *m_jogProcess;
+    JogShuttleAction* m_jogShuttle;
 #endif /* NO_JOGSHUTTLE */
 
     KRecentFilesAction *m_fileOpenRecent;
@@ -226,6 +253,8 @@ private:
     KAction *m_zoomOut;
     KAction *m_loopZone;
     KAction *m_playZone;
+    KAction *m_loopClip;
+    KSelectAction *m_loadLayout;
     StatusBarMessageLabel *m_messageLabel;
     QActionGroup *m_clipTypeGroup;
     KActionCollection *m_effectsActionCollection;
@@ -238,7 +267,6 @@ private:
     void saveOptions();
 #ifndef NO_JOGSHUTTLE
     void activateShuttleDevice();
-    void slotShuttleAction(int code);
 #endif /* NO_JOGSHUTTLE */
     void connectDocumentInfo(KdenliveDoc *doc);
     void findAhead();
@@ -270,18 +298,24 @@ private:
     * @return The mimetype */
     QString getMimeType();
 
+    /** @brief Populates the "load layout" menu. */
+    void loadLayouts();
+
+    StopmotionWidget *m_stopmotion;
+
 public slots:
     /** @brief Prepares opening @param url.
     *
     * Checks if already open and whether backup exists */
     void openFile(const KUrl &url);
     void slotGotProgressInfo(const QString &message, int progress);
+    void slotReloadEffects();
     Q_SCRIPTABLE void setRenderingProgress(const QString &url, int progress);
     Q_SCRIPTABLE void setRenderingFinished(const QString &url, int status, const QString &error);
 
+
 private slots:
     void newFile(bool showProjectSettings = true, bool force = false);
-    void queryQuit();
     void activateDocument();
     void connectDocument(TrackView*, KdenliveDoc*);
 
@@ -316,6 +350,8 @@ private slots:
     void slotEditProfiles();
     void slotDetectAudioDriver();
     void slotEditProjectSettings();
+    /** @brief Change current document MLT profile. */
+    void slotUpdateProjectProfile(const QString &profile);
     void slotDisplayActionMessage(QAction *a);
 
     /** @brief Turns automatic splitting of audio and video on/off. */
@@ -354,6 +390,13 @@ private slots:
     void slotDeleteClipMarker();
     void slotDeleteAllClipMarkers();
     void slotEditClipMarker();
+
+    /** @brief Adds marker or auide at the current position without showing the marker dialog.
+     *
+     * Adds a marker if clip monitor is active, otherwise a guide.
+     * The comment is set to the current position (therefore not dialog).
+     * This can be useful to mark something during playback. */
+    void slotAddMarkerGuideQuickly();
     void slotCutTimelineClip();
     void slotInsertClipOverwrite();
     void slotSelectTimelineClip();
@@ -363,16 +406,11 @@ private slots:
     void slotSelectAddTimelineClip();
     void slotSelectAddTimelineTransition();
     void slotAddVideoEffect(QAction *result);
-    void slotAddAudioEffect(QAction *result);
-    void slotAddCustomEffect(QAction *result);
     void slotAddTransition(QAction *result);
     void slotAddProjectClip(KUrl url);
-#ifndef NO_JOGSHUTTLE
-    void slotShuttleButton(int code);
-#endif /* NO_JOGSHUTTLE */
     void slotShowClipProperties(DocClipBase *clip);
     void slotShowClipProperties(QList <DocClipBase *>cliplist, QMap<QString, QString> commonproperties);
-    void slotActivateEffectStackView();
+    void slotActivateEffectStackView(ClipItem* item = NULL, int ix = -1, bool raise = true);
     void slotActivateTransitionView(Transition *);
     void slotChangeTool(QAction * action);
     void slotChangeEdit(QAction * action);
@@ -400,7 +438,6 @@ private slots:
     void slotCopy();
     void slotPaste();
     void slotPasteEffects();
-    void slotReloadEffects();
 
     void slotAdjustClipMonitor();
     void slotAdjustProjectMonitor();
@@ -424,7 +461,6 @@ private slots:
     /** @brief Lets the sampleplugin create a generator.  */
     void generateClip();
     void slotZoneMoved(int start, int end);
-    void slotUpdatePreviewSettings();
     void slotDvdWizard(const QString &url = QString(), const QString &profile = "dv_pal");
     void slotGroupClips();
     void slotUnGroupClips();
@@ -465,16 +501,38 @@ private slots:
     void slotDeleteProjectClips(QStringList ids, QMap<QString, QString> folderids);
     void slotShowTitleBars(bool show);
     void slotSwitchTitles();
+    /** @brief Update the capture folder if user asked a change. */
+    void slotUpdateCaptureFolder();
+
+    /** @brief Apply new properties to a clip */
+    void slotApplyNewClipProperties(const QString id, QMap <QString, QString> props, QMap <QString, QString> newprops, bool refresh, bool reload);
+
+    /** @brief Delete a clip from current project */
+    void slotDeleteClip(const QString &id);
+
+    /** @brief Saves the widgets layout */
+    void slotSaveLayout(QAction*);
+    void slotLoadLayout(QAction*);
 
     /** @brief The monitor informs that it needs (or not) to have frames sent by the renderer. */
     void slotMonitorRequestRenderFrame(bool request);
     /** @brief Check if someone needs the render frame sent. */
-    void slotUpdateScopeFrameRequest();
+    void slotUpdateGfxScopeFrameRequest();
     /** @brief Check if someone needs the render frame sent. */
-    void slotDoUpdateScopeFrameRequest();
+    void slotDoUpdateGfxScopeFrameRequest();
+    void slotUpdateAudioScopeFrameRequest();
+    void slotDoUpdateAudioScopeFrameRequest();
     /** @brief When switching between monitors, update the visible scopes. */
     void slotUpdateColorScopes();
-
+    /** @brief Switch current monitor to fullscreen. */
+    void slotSwitchFullscreen();
+    /** @brief Open the stopmotion dialog. */
+    void slotOpenStopmotion();
+    /** @brief Implements all the actions that are int he ActionsCollection. */
+    void slotDoAction(const QString& action_name);
+    /** @brief Update project because the use of proxy clips was enabled / disabled. */
+    void slotUpdateProxySettings();
+ 
 signals:
     Q_SCRIPTABLE void abortRenderJob(const QString &url);
 };
