@@ -30,16 +30,20 @@ MarkerDialog::MarkerDialog(DocClipBase *clip, CommentedTime t, Timecode tc, cons
         QDialog(parent),
         m_producer(NULL),
         m_profile(NULL),
-        m_clip(clip),
-        m_tc(tc)
+        m_clip(clip)
 {
     setFont(KGlobalSettings::toolBarFont());
-    m_fps = m_tc.fps();
     setupUi(this);
     setWindowTitle(caption);
+
+    m_in = new TimecodeDisplay(tc, this);
+    inputLayout->addWidget(m_in);
+    m_in->setValue(t.time());
+
     m_previewTimer = new QTimer(this);
 
     if (m_clip != NULL) {
+        m_in->setRange(0, m_clip->duration().frames(tc.fps()));
         m_previewTimer->setInterval(500);
         connect(m_previewTimer, SIGNAL(timeout()), this, SLOT(slotUpdateThumb()));
         m_profile = new Mlt::Profile((char*) KdenliveSettings::current_profile().data());
@@ -57,6 +61,7 @@ MarkerDialog::MarkerDialog(DocClipBase *clip, CommentedTime t, Timecode tc, cons
         if (width % 2 == 1) width++;
         QPixmap p(width, 100);
         QString colour = clip->getProperty("colour");
+
         switch (m_clip->clipType()) {
         case VIDEO:
         case AV:
@@ -65,7 +70,7 @@ MarkerDialog::MarkerDialog(DocClipBase *clip, CommentedTime t, Timecode tc, cons
             connect(this, SIGNAL(updateThumb()), m_previewTimer, SLOT(start()));
         case IMAGE:
         case TEXT:
-            p = QPixmap::fromImage(KThumb::getFrame(m_producer, t.time().frames(m_fps), width, 100));
+            p = QPixmap::fromImage(KThumb::getFrame(m_producer, m_in->getValue(), width, 100));
             break;
         case COLOR:
             colour = colour.replace(0, 2, "#");
@@ -74,26 +79,21 @@ MarkerDialog::MarkerDialog(DocClipBase *clip, CommentedTime t, Timecode tc, cons
         default:
             p.fill(Qt::black);
         }
+
         if (!p.isNull()) {
             clip_thumb->setFixedWidth(p.width());
             clip_thumb->setFixedHeight(p.height());
             clip_thumb->setPixmap(p);
         }
-        connect(marker_position, SIGNAL(textChanged(const QString &)), this, SIGNAL(updateThumb()));
-    } else clip_thumb->setHidden(true);
-
-    if (KdenliveSettings::frametimecode()) {
-        marker_position->setInputMask("000000000000");
-        marker_position->setText(QString::number((int) t.time().frames(m_fps)));
-    } else marker_position->setText(tc.getTimecode(t.time()));
+        connect(m_in, SIGNAL(editingFinished()), this, SIGNAL(updateThumb()));
+    } else {
+        clip_thumb->setHidden(true);
+    }
 
     marker_comment->setText(t.comment());
     marker_comment->selectAll();
     marker_comment->setFocus();
 
-    connect(position_up, SIGNAL(clicked()), this, SLOT(slotTimeUp()));
-    connect(position_down, SIGNAL(clicked()), this, SLOT(slotTimeDown()));
-
     adjustSize();
 }
 
@@ -107,52 +107,19 @@ MarkerDialog::~MarkerDialog()
 void MarkerDialog::slotUpdateThumb()
 {
     m_previewTimer->stop();
-    int pos;
-    if (KdenliveSettings::frametimecode()) pos = marker_position->text().toInt();
-    else pos = m_tc.getFrameCount(marker_position->text());
+    int pos = m_in->getValue();
     int width = 100.0 * m_dar;
     if (width % 2 == 1) width++;
     QPixmap p = QPixmap::fromImage(KThumb::getFrame(m_producer, pos, width, 100));
-    if (!p.isNull()) clip_thumb->setPixmap(p);
-    else kDebug() << "!!!!!!!!!!!  ERROR CREATING THUMB";
-}
-
-void MarkerDialog::slotTimeUp()
-{
-    int duration;
-    if (KdenliveSettings::frametimecode()) duration = marker_position->text().toInt();
-    else duration = m_tc.getFrameCount(marker_position->text());
-    if (m_clip && duration >= m_clip->duration().frames(m_fps)) return;
-    duration ++;
-    if (KdenliveSettings::frametimecode()) marker_position->setText(QString::number(duration));
-    else marker_position->setText(m_tc.getTimecode(GenTime(duration, m_fps)));
-}
-
-void MarkerDialog::slotTimeDown()
-{
-    int duration;
-    if (KdenliveSettings::frametimecode()) duration = marker_position->text().toInt();
-    else duration = m_tc.getFrameCount(marker_position->text());
-    if (duration <= 0) return;
-    duration --;
-    if (KdenliveSettings::frametimecode()) marker_position->setText(QString::number(duration));
-    else marker_position->setText(m_tc.getTimecode(GenTime(duration, m_fps)));
+    if (!p.isNull())
+        clip_thumb->setPixmap(p);
+    else
+        kDebug() << "!!!!!!!!!!!  ERROR CREATING THUMB";
 }
 
 CommentedTime MarkerDialog::newMarker()
 {
-    if (KdenliveSettings::frametimecode()) return CommentedTime(GenTime(marker_position->text().toInt(), m_fps), marker_comment->text());
-    return CommentedTime(GenTime(m_tc.getFrameCount(marker_position->text()), m_fps), marker_comment->text());
-}
-
-void MarkerDialog::wheelEvent(QWheelEvent * event)
-{
-    if (marker_position->underMouse() || clip_thumb->underMouse()) {
-        if (event->delta() > 0)
-            slotTimeUp();
-        else
-            slotTimeDown();
-    }
+    return CommentedTime(m_in->gentime(), marker_comment->text());
 }
 
 #include "markerdialog.moc"
