@@ -23,7 +23,9 @@
 #include "monitormanager.h"
 #include "smallruler.h"
 #include "docclipbase.h"
+#include "abstractclipitem.h"
 #include "monitorscene.h"
+#include "monitoreditwidget.h"
 #include "kdenlivesettings.h"
 
 #include <KDebug>
@@ -41,70 +43,82 @@
 #include <QLabel>
 #include <QIntValidator>
 #include <QVBoxLayout>
-#include <QGraphicsView>
 
 
 Monitor::Monitor(QString name, MonitorManager *manager, QString profile, QWidget *parent) :
-        QWidget(parent),
-        render(NULL),
-        m_name(name),
-        m_monitorManager(manager),
-        m_currentClip(NULL),
-        m_ruler(new SmallRuler(m_monitorManager)),
-        m_overlay(NULL),
-        m_isActive(false),
-        m_scale(1),
-        m_length(0),
-        m_dragStarted(false),
-        m_effectScene(NULL),
-        m_effectView(NULL)
+    QWidget(parent),
+    render(NULL),
+    m_name(name),
+    m_monitorManager(manager),
+    m_currentClip(NULL),
+    m_ruler(new SmallRuler(m_monitorManager)),
+    m_overlay(NULL),
+    m_isActive(false),
+    m_scale(1),
+    m_length(0),
+    m_dragStarted(false),
+    m_monitorRefresh(NULL),
+    m_effectWidget(NULL),
+    m_selectedClip(NULL),
+    m_loopClipTransition(true),
+    m_editMarker(NULL)
+
 {
-    m_ui.setupUi(this);
     QVBoxLayout *layout = new QVBoxLayout;
     layout->setContentsMargins(0, 0, 0, 0);
+    layout->setSpacing(0);
+
+    // Video widget holder
+    m_videoBox = new VideoContainer(this);
+    m_videoBox->setContentsMargins(0, 0, 0, 0);
+    m_videoBox->setSizePolicy(QSizePolicy::Preferred, QSizePolicy::Preferred);
+    layout->addWidget(m_videoBox, 10);
+    layout->addStretch();
+
+    // Get base size for icons
+    int s = style()->pixelMetric(QStyle::PM_SmallIconSize);
+
+    // Monitor ruler
     layout->addWidget(m_ruler);
-    m_ui.ruler_frame->setLayout(layout);
-    setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
-    setMinimumHeight(200);
-    QToolBar *toolbar = new QToolBar(name, this);
-    QVBoxLayout *layout2 = new QVBoxLayout;
-    layout2->setContentsMargins(0, 0, 0, 0);
+    // Tool bar buttons
+    m_toolbar = new QToolBar(name, this);
+    m_toolbar->setIconSize(QSize(s, s));
 
     m_playIcon = KIcon("media-playback-start");
     m_pauseIcon = KIcon("media-playback-pause");
 
     if (name != "chapter") {
-        toolbar->addAction(KIcon("kdenlive-zone-start"), i18n("Set zone start"), this, SLOT(slotSetZoneStart()));
-        toolbar->addAction(KIcon("kdenlive-zone-end"), i18n("Set zone end"), this, SLOT(slotSetZoneEnd()));
+        m_toolbar->addAction(KIcon("kdenlive-zone-start"), i18n("Set zone start"), this, SLOT(slotSetZoneStart()));
+        m_toolbar->addAction(KIcon("kdenlive-zone-end"), i18n("Set zone end"), this, SLOT(slotSetZoneEnd()));
     } else {
         m_ruler->setZone(-3, -2);
     }
 
-    toolbar->addAction(KIcon("media-seek-backward"), i18n("Rewind"), this, SLOT(slotRewind()));
-    //toolbar->addAction(KIcon("media-skip-backward"), i18n("Rewind 1 frame"), this, SLOT(slotRewindOneFrame()));
+    m_toolbar->addAction(KIcon("media-seek-backward"), i18n("Rewind"), this, SLOT(slotRewind()));
+    //m_toolbar->addAction(KIcon("media-skip-backward"), i18n("Rewind 1 frame"), this, SLOT(slotRewindOneFrame()));
 
-    QToolButton *playButton = new QToolButton(toolbar);
+    QToolButton *playButton = new QToolButton(m_toolbar);
     m_playMenu = new QMenu(i18n("Play..."), this);
     m_playAction = m_playMenu->addAction(m_playIcon, i18n("Play"));
-    m_playAction->setCheckable(true);
+    //m_playAction->setCheckable(true);
     connect(m_playAction, SIGNAL(triggered()), this, SLOT(slotPlay()));
 
     playButton->setMenu(m_playMenu);
     playButton->setPopupMode(QToolButton::MenuButtonPopup);
-    toolbar->addWidget(playButton);
+    m_toolbar->addWidget(playButton);
 
-    //toolbar->addAction(KIcon("media-skip-forward"), i18n("Forward 1 frame"), this, SLOT(slotForwardOneFrame()));
-    toolbar->addAction(KIcon("media-seek-forward"), i18n("Forward"), this, SLOT(slotForward()));
+    //m_toolbar->addAction(KIcon("media-skip-forward"), i18n("Forward 1 frame"), this, SLOT(slotForwardOneFrame()));
+    m_toolbar->addAction(KIcon("media-seek-forward"), i18n("Forward"), this, SLOT(slotForward()));
 
     playButton->setDefaultAction(m_playAction);
 
     if (name != "chapter") {
-        QToolButton *configButton = new QToolButton(toolbar);
+        QToolButton *configButton = new QToolButton(m_toolbar);
         m_configMenu = new QMenu(i18n("Misc..."), this);
         configButton->setIcon(KIcon("system-run"));
         configButton->setMenu(m_configMenu);
         configButton->setPopupMode(QToolButton::QToolButton::InstantPopup);
-        toolbar->addWidget(configButton);
+        m_toolbar->addWidget(configButton);
 
         if (name == "clip") {
             m_markerMenu = new QMenu(i18n("Go to marker..."), this);
@@ -116,40 +130,57 @@ Monitor::Monitor(QString name, MonitorManager *manager, QString profile, QWidget
         m_configMenu->addAction(KIcon("transform-scale"), i18n("Resize (50%)"), this, SLOT(slotSetSizeOneToTwo()));
     }
 
-    QWidget *spacer = new QWidget(this);
-    spacer->setSizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::MinimumExpanding);
-    toolbar->addWidget(spacer);
-    m_timePos = new TimecodeDisplay(m_monitorManager->timecode(), this);
-    toolbar->addWidget(m_timePos);
-    connect(m_timePos, SIGNAL(editingFinished()), this, SLOT(slotSeek()));
+    // Create Volume slider popup
+    m_volumePopup = new QFrame(this, Qt::Popup);
+    QVBoxLayout *poplayout = new QVBoxLayout;
+    poplayout->setContentsMargins(0, 0, 0, 0);
+    m_audioSlider = new QSlider(Qt::Vertical);
+    m_audioSlider->setRange(0, 100);
+    poplayout->addWidget(m_audioSlider);
+    m_volumePopup->setLayout(poplayout);
+    KIcon icon;
+    if (KdenliveSettings::volume() == 0) icon = KIcon("audio-volume-muted");
+    else icon = KIcon("audio-volume-medium");
 
-    layout2->addWidget(toolbar);
-    m_ui.button_frame->setLayout(layout2);
-    const int toolHeight = toolbar->height();
-    m_ui.button_frame->setMinimumHeight(toolHeight);
+    m_volumeWidget = m_toolbar->widgetForAction(m_toolbar->addAction(icon, i18n("Audio volume"), this, SLOT(slotShowVolume())));
 
-    //m_ruler->setPixelPerMark(3);
+    // we need to show / hide the popup once so that it's geometry can be calculated in slotShowVolume
+    m_volumePopup->show();
+    m_volumePopup->hide();
+
+    setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
+    setLayout(layout);
+    setMinimumHeight(200);
 
     if (profile.isEmpty()) profile = KdenliveSettings::current_profile();
 
-    QVBoxLayout *rendererBox = new QVBoxLayout(m_ui.video_frame);
-    rendererBox->setContentsMargins(0, 0, 0, 0);
+    bool monitorCreated = false;
 #ifdef Q_WS_MAC
-    m_glWidget = new VideoGLWidget(m_ui.video_frame);
-    rendererBox->addWidget(m_glWidget);
-    render = new Render(m_name, (int) m_ui.video_frame->winId(), -1, profile, this);
-    m_glWidget->setImageAspectRatio(render->dar());
-    m_glWidget->setBackgroundColor(KdenliveSettings::window_background());
-    m_glWidget->resize(m_ui.video_frame->size());
-    connect(render, SIGNAL(showImageSignal(QImage)), m_glWidget, SLOT(showImage(QImage)));
-    m_monitorRefresh = 0;
-#else
-    m_monitorRefresh = new MonitorRefresh(m_ui.video_frame);
-    rendererBox->addWidget(m_monitorRefresh);
-    render = new Render(m_name, (int) m_monitorRefresh->winId(), -1, profile, this);
-    m_monitorRefresh->setRenderer(render);
+    createOpenGlWidget(m_videoBox, profile);
+    monitorCreated = true;
+    //m_glWidget->setFixedSize(width, height);
+#elif defined (USE_OPEN_GL)
+    if (KdenliveSettings::openglmonitors()) {
+        monitorCreated = createOpenGlWidget(m_videoBox, profile);
+    }
+#endif
+    QVBoxLayout *lay = new QVBoxLayout;
+    lay->setContentsMargins(0, 0, 0, 0);
+    if (!monitorCreated) {
+        m_monitorRefresh = new MonitorRefresh;
+        lay->addWidget(m_monitorRefresh);
+        m_videoBox->setLayout(lay);
+        render = new Render(m_name, (int) m_monitorRefresh->winId(), profile, this);
+        m_monitorRefresh->setRenderer(render);
+    }
+#if defined (USE_OPEN_GL)
+    else if (m_glWidget) {
+        lay->addWidget(m_glWidget);
+        m_videoBox->setLayout(lay);
+    }
 #endif
 
+    connect(m_audioSlider, SIGNAL(valueChanged(int)), this, SLOT(slotSetVolume(int)));
     connect(m_ruler, SIGNAL(seekRenderer(int)), this, SLOT(slotSeek(int)));
     connect(render, SIGNAL(durationChanged(int)), this, SLOT(adjustRulerSize(int)));
     connect(render, SIGNAL(rendererStopped(int)), this, SLOT(rendererStopped(int)));
@@ -163,22 +194,24 @@ Monitor::Monitor(QString name, MonitorManager *manager, QString profile, QWidget
     } else {
         connect(m_ruler, SIGNAL(zoneChanged(QPoint)), this, SLOT(setClipZone(QPoint)));
     }
-#ifndef Q_WS_MAC
-    m_monitorRefresh->show();
-#endif
+
+    if (m_monitorRefresh) m_monitorRefresh->show();
 
     if (name == "project") {
-        m_effectScene = new MonitorScene(render);
-        m_effectView = new QGraphicsView(m_effectScene, m_ui.video_frame);
-        m_effectView->setRenderHints(QFlags<QPainter::RenderHint>());
-        m_effectView->scale(((double) render->renderWidth()) / render->frameRenderWidth(), 1.0);
-        rendererBox->addWidget(m_effectView);
-        m_effectView->setMouseTracking(true);
-        m_effectScene->setUp();
-        m_effectView->hide();
+        m_effectWidget = new MonitorEditWidget(render, m_videoBox);
+        m_toolbar->addAction(m_effectWidget->getVisibilityAction());
+        lay->addWidget(m_effectWidget);
+        m_effectWidget->hide();
     }
 
-    kDebug() << "/////// BUILDING MONITOR, ID: " << m_ui.video_frame->winId();
+    QWidget *spacer = new QWidget(this);
+    spacer->setSizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::Preferred);
+    m_toolbar->addWidget(spacer);
+    m_timePos = new TimecodeDisplay(m_monitorManager->timecode(), this);
+    m_toolbar->addWidget(m_timePos);
+    connect(m_timePos, SIGNAL(editingFinished()), this, SLOT(slotSeek()));
+    m_toolbar->setMaximumHeight(s * 1.5);
+    layout->addWidget(m_toolbar);
 }
 
 Monitor::~Monitor()
@@ -186,28 +219,61 @@ Monitor::~Monitor()
     delete m_ruler;
     delete m_timePos;
     delete m_overlay;
-    if (m_name == "project") {
-        delete m_effectView;
-        delete m_effectScene;
-    }
+    if (m_effectWidget)
+        delete m_effectWidget;
     delete m_monitorRefresh;
     delete render;
 }
 
+QWidget *Monitor::container()
+{
+    return m_videoBox;
+}
+
 QString Monitor::name() const
 {
     return m_name;
 }
 
-void Monitor::setupMenu(QMenu *goMenu, QAction *playZone, QAction *loopZone, QMenu *markerMenu)
+#if defined(Q_WS_MAC) || defined(USE_OPEN_GL)
+bool Monitor::createOpenGlWidget(QWidget *parent, const QString profile)
+{
+    render = new Render(m_name, 0, profile, this);
+    m_glWidget = new VideoGLWidget(parent);
+    if (m_glWidget == NULL) {
+        // Creation failed, we are in trouble...
+        return false;
+    }
+    m_glWidget->setImageAspectRatio(render->dar());
+    m_glWidget->setBackgroundColor(KdenliveSettings::window_background());
+    connect(render, SIGNAL(showImageSignal(QImage)), m_glWidget, SLOT(showImage(QImage)));
+    return true;
+}
+#endif
+
+void Monitor::setupMenu(QMenu *goMenu, QAction *playZone, QAction *loopZone, QMenu *markerMenu, QAction *loopClip)
 {
     m_contextMenu = new QMenu(this);
     m_contextMenu->addMenu(m_playMenu);
-    if (goMenu) m_contextMenu->addMenu(goMenu);
-    if (markerMenu) m_contextMenu->addMenu(markerMenu);
+    if (goMenu)
+        m_contextMenu->addMenu(goMenu);
+    if (markerMenu) {
+        m_contextMenu->addMenu(markerMenu);
+        QList <QAction *>list = markerMenu->actions();
+        for (int i = 0; i < list.count(); i++) {
+            if (list.at(i)->data().toString() == "edit_marker") {
+                m_editMarker = list.at(i);
+                break;
+            }
+        }
+    }
 
     m_playMenu->addAction(playZone);
     m_playMenu->addAction(loopZone);
+    if (loopClip) {
+        m_loopClipAction = loopClip;
+        m_playMenu->addAction(loopClip);
+    }
 
     //TODO: add save zone to timeline monitor when fixed
     if (m_name == "clip") {
@@ -218,11 +284,9 @@ void Monitor::setupMenu(QMenu *goMenu, QAction *playZone, QAction *loopZone, QMe
     m_contextMenu->addAction(extractFrame);
 
     if (m_name != "clip") {
-#ifndef Q_WS_MAC
         QAction *splitView = m_contextMenu->addAction(KIcon("view-split-left-right"), i18n("Split view"), render, SLOT(slotSplitView(bool)));
         splitView->setCheckable(true);
         m_configMenu->addAction(splitView);
-#endif
     } else {
         QAction *setThumbFrame = m_contextMenu->addAction(KIcon("document-new"), i18n("Set current image as thumbnail"), this, SLOT(slotSetThumbFrame()));
         m_configMenu->addAction(setThumbFrame);
@@ -262,7 +326,7 @@ void Monitor::slotSetSizeOneToOne()
         height = height * 0.8;
     }
     kDebug() << "// MONITOR; set SIZE: " << width << ", " << height;
-    m_ui.video_frame->setFixedSize(width, height);
+    m_videoBox->setFixedSize(width, height);
     updateGeometry();
     adjustSize();
     //m_ui.video_frame->setMinimumSize(0, 0);
@@ -282,7 +346,7 @@ void Monitor::slotSetSizeOneToTwo()
         height = height * 0.8;
     }
     kDebug() << "// MONITOR; set SIZE: " << width << ", " << height;
-    m_ui.video_frame->setFixedSize(width, height);
+    m_videoBox->setFixedSize(width, height);
     updateGeometry();
     adjustSize();
     //m_ui.video_frame->setMinimumSize(0, 0);
@@ -291,7 +355,7 @@ void Monitor::slotSetSizeOneToTwo()
 
 void Monitor::resetSize()
 {
-    m_ui.video_frame->setMinimumSize(0, 0);
+    m_videoBox->setMinimumSize(0, 0);
 }
 
 DocClipBase *Monitor::activeClip()
@@ -388,18 +452,25 @@ void Monitor::slotSetZoneEnd()
 void Monitor::mousePressEvent(QMouseEvent * event)
 {
     if (event->button() != Qt::RightButton) {
-        if (m_ui.video_frame->underMouse()) {
+        if (m_videoBox->underMouse() && (!m_overlay || !m_overlay->underMouse())) {
             m_dragStarted = true;
             m_DragStartPosition = event->pos();
         }
-    } else m_contextMenu->popup(event->globalPos());
+    } else if (!m_effectWidget || !m_effectWidget->isVisible()) {
+        m_contextMenu->popup(event->globalPos());
+    }
+}
+
+void Monitor::slotSwitchFullScreen()
+{
+    m_videoBox->switchFullScreen();
 }
 
 // virtual
 void Monitor::mouseReleaseEvent(QMouseEvent * event)
 {
     if (m_dragStarted) {
-        if (m_ui.video_frame->underMouse() && (!m_effectView || !m_effectView->isVisible())) {
+        if (m_videoBox->underMouse() && (!m_effectWidget || !m_effectWidget->isVisible())) {
             if (isActive()) slotPlay();
             else activateMonitor();
         } else QWidget::mouseReleaseEvent(event);
@@ -468,12 +539,18 @@ QStringList Monitor::mimeTypes() const
 // virtual
 void Monitor::wheelEvent(QWheelEvent * event)
 {
-    if (event->modifiers() == Qt::ControlModifier) {
+    slotMouseSeek(event->delta(), event->modifiers() == Qt::ControlModifier);
+    event->accept();
+}
+
+void Monitor::slotMouseSeek(int eventDelta, bool fast)
+{
+    if (fast) {
         int delta = m_monitorManager->timecode().fps();
-        if (event->delta() > 0) delta = 0 - delta;
+        if (eventDelta > 0) delta = 0 - delta;
         slotSeek(render->seekFramePosition() - delta);
     } else {
-        if (event->delta() >= 0) slotForwardOneFrame();
+        if (eventDelta >= 0) slotForwardOneFrame();
         else slotRewindOneFrame();
     }
 }
@@ -484,12 +561,18 @@ void Monitor::slotSetThumbFrame()
         return;
     }
     m_currentClip->setClipThumbFrame((uint) render->seekFramePosition());
-    emit refreshClipThumbnail(m_currentClip->getId());
+    emit refreshClipThumbnail(m_currentClip->getId(), true);
 }
 
 void Monitor::slotExtractCurrentFrame()
 {
-    QImage frame = render->extractFrame(render->seekFramePosition());
+    QImage frame;
+    // check if we are using a proxy
+    if (m_currentClip && !m_currentClip->getProperty("proxy").isEmpty() && m_currentClip->getProperty("proxy") != "-") {
+        // using proxy, use original clip url to get frame
+        frame = render->extractFrame(render->seekFramePosition(), m_currentClip->fileURL().path());
+    }
+    else frame = render->extractFrame(render->seekFramePosition());
     KFileDialog *fs = new KFileDialog(KUrl(), "image/png", this);
     fs->setOperationMode(KFileDialog::Saving);
     fs->setMode(KFile::File);
@@ -591,7 +674,7 @@ void Monitor::slotRewind(double speed)
         if (currentspeed >= 0) render->play(-2);
         else render->play(currentspeed * 2);
     } else render->play(speed);
-    m_playAction->setChecked(true);
+    //m_playAction->setChecked(true);
     m_playAction->setIcon(m_pauseIcon);
 }
 
@@ -603,7 +686,7 @@ void Monitor::slotForward(double speed)
         if (currentspeed <= 1) render->play(2);
         else render->play(currentspeed * 2);
     } else render->play(speed);
-    m_playAction->setChecked(true);
+    //m_playAction->setChecked(true);
     m_playAction->setIcon(m_pauseIcon);
 }
 
@@ -637,24 +720,11 @@ void Monitor::rendererStopped(int pos)
         m_timePos->setValue(pos);
     }
     disconnect(m_playAction, SIGNAL(triggered()), this, SLOT(slotPlay()));
-    m_playAction->setChecked(false);
+    //m_playAction->setChecked(false);
     connect(m_playAction, SIGNAL(triggered()), this, SLOT(slotPlay()));
     m_playAction->setIcon(m_playIcon);
 }
 
-void Monitor::initMonitor()
-{
-    kDebug() << "/////// INITING MONITOR, ID: " << m_ui.video_frame->winId();
-}
-
-// virtual
-/*void Monitor::resizeEvent(QResizeEvent * event) {
-    QWidget::resizeEvent(event);
-    adjustRulerSize(-1);
-    if (render && m_isActive) render->doRefresh();
-    //
-}*/
-
 void Monitor::adjustRulerSize(int length)
 {
     if (length > 0) m_length = length;
@@ -687,13 +757,20 @@ void Monitor::refreshMonitor(bool visible)
     }
 }
 
+void Monitor::refreshMonitor()
+{
+    if (m_isActive) {
+        render->doRefresh();
+    }
+}
+
 void Monitor::pause()
 {
     if (render == NULL) return;
     activateMonitor();
     render->pause();
     //m_playAction->setChecked(true);
-    //m_playAction->setIcon(m_pauseIcon);
+    m_playAction->setIcon(m_playIcon);
 }
 
 void Monitor::slotPlay()
@@ -701,10 +778,10 @@ void Monitor::slotPlay()
     if (render == NULL) return;
     activateMonitor();
     if (render->playSpeed() == 0) {
-        m_playAction->setChecked(true);
+        //m_playAction->setChecked(true);
         m_playAction->setIcon(m_pauseIcon);
     } else {
-        m_playAction->setChecked(false);
+        //m_playAction->setChecked(false);
         m_playAction->setIcon(m_playIcon);
     }
     render->switchPlay();
@@ -716,7 +793,7 @@ void Monitor::slotPlayZone()
     activateMonitor();
     QPoint p = m_ruler->zone();
     render->playZone(GenTime(p.x(), m_monitorManager->timecode().fps()), GenTime(p.y(), m_monitorManager->timecode().fps()));
-    m_playAction->setChecked(true);
+    //m_playAction->setChecked(true);
     m_playAction->setIcon(m_pauseIcon);
 }
 
@@ -726,7 +803,17 @@ void Monitor::slotLoopZone()
     activateMonitor();
     QPoint p = m_ruler->zone();
     render->loopZone(GenTime(p.x(), m_monitorManager->timecode().fps()), GenTime(p.y(), m_monitorManager->timecode().fps()));
-    m_playAction->setChecked(true);
+    //m_playAction->setChecked(true);
+    m_playAction->setIcon(m_pauseIcon);
+}
+
+void Monitor::slotLoopClip()
+{
+    if (render == NULL || m_selectedClip == NULL)
+        return;
+    activateMonitor();
+    render->loopZone(m_selectedClip->startPos(), m_selectedClip->endPos());
+    //m_playAction->setChecked(true);
     m_playAction->setIcon(m_pauseIcon);
 }
 
@@ -739,7 +826,7 @@ void Monitor::slotSetXml(DocClipBase *clip, QPoint zone, const int position)
         render->setProducer(NULL, -1);
         return;
     }
-    if (m_currentClip != NULL) activateMonitor();
+    if (m_currentClip != NULL || clip != NULL) activateMonitor();
     if (clip != m_currentClip) {
         m_currentClip = clip;
         updateMarkers(clip);
@@ -747,10 +834,10 @@ void Monitor::slotSetXml(DocClipBase *clip, QPoint zone, const int position)
             // MLT CONSUMER is broken
             kDebug(QtWarningMsg) << "ERROR, Cannot start monitor";
         }
-    } else if (position != -1) render->seek(GenTime(position, m_monitorManager->timecode().fps()));
+    } else if (position != -1) render->seek(position);
     if (!zone.isNull()) {
         m_ruler->setZone(zone.x(), zone.y());
-        render->seek(GenTime(zone.x(), m_monitorManager->timecode().fps()));
+        render->seek(zone.x());
     }
 }
 
@@ -781,10 +868,8 @@ void Monitor::resetProfile(const QString profile)
     m_timePos->updateTimeCode(m_monitorManager->timecode());
     if (render == NULL) return;
     render->resetProfile(profile);
-    if (m_effectScene) {
-        m_effectView->scale(((double) render->renderWidth()) / render->frameRenderWidth(), 1.0);
-        m_effectScene->resetProfile();
-    }
+    if (m_effectWidget)
+        m_effectWidget->resetProfile(render);
 }
 
 void Monitor::saveSceneList(QString path, QDomElement info)
@@ -815,19 +900,40 @@ void Monitor::slotSwitchMonitorInfo(bool show)
     KdenliveSettings::setDisplayMonitorInfo(show);
     if (show) {
         if (m_overlay) return;
-#ifndef Q_WS_MAC
-        m_overlay = new Overlay(m_monitorRefresh);
-        m_overlay->raise();
-        m_overlay->setHidden(true);
-#else
-        m_overlay = new Overlay(m_glWidget);
+        if (m_monitorRefresh == NULL) {
+            // Using OpenGL display
+#if defined(Q_WS_MAC) || defined(USE_OPEN_GL)
+            if (m_glWidget->layout()) delete m_glWidget->layout();
+            m_overlay = new Overlay();
+            connect(m_overlay, SIGNAL(editMarker()), this, SLOT(slotEditMarker()));
+            QVBoxLayout *layout = new QVBoxLayout;
+            layout->addStretch(10);
+            layout->addWidget(m_overlay);
+            m_glWidget->setLayout(layout);
 #endif
+        } else {
+            if (m_monitorRefresh->layout()) delete m_monitorRefresh->layout();
+            m_overlay = new Overlay();
+            connect(m_overlay, SIGNAL(editMarker()), this, SLOT(slotEditMarker()));
+            QVBoxLayout *layout = new QVBoxLayout;
+            layout->addStretch(10);
+            layout->addWidget(m_overlay);
+            m_monitorRefresh->setLayout(layout);
+            m_overlay->raise();
+            m_overlay->setHidden(true);
+        }
+        checkOverlay();
     } else {
         delete m_overlay;
         m_overlay = NULL;
     }
 }
 
+void Monitor::slotEditMarker()
+{
+    if (m_editMarker) m_editMarker->trigger();
+}
+
 void Monitor::updateTimecodeFormat()
 {
     m_timePos->slotUpdateTimeCodeFormat();
@@ -843,39 +949,93 @@ QStringList Monitor::getZoneInfo() const
     return result;
 }
 
+void Monitor::slotSetSelectedClip(AbstractClipItem* item)
+{
+    if (item) {
+        m_loopClipAction->setEnabled(true);
+        m_selectedClip = item;
+    } else {
+        m_loopClipAction->setEnabled(false);
+    }
+}
+
+void Monitor::slotSetSelectedClip(ClipItem* item)
+{
+    if (item || (!item && !m_loopClipTransition)) {
+        m_loopClipTransition = false;
+        slotSetSelectedClip((AbstractClipItem*)item);
+    }
+}
+
+void Monitor::slotSetSelectedClip(Transition* item)
+{
+    if (item || (!item && m_loopClipTransition)) {
+        m_loopClipTransition = true;
+        slotSetSelectedClip((AbstractClipItem*)item);
+    }
+}
+
+
 void Monitor::slotEffectScene(bool show)
 {
     if (m_name == "project") {
-#ifdef Q_WS_MAC
-        m_glWidget->setVisible(!show);
-#else
-        m_monitorRefresh->setVisible(!show);
+        if (m_monitorRefresh) {
+            m_monitorRefresh->setVisible(!show);
+        } else {
+#if defined(Q_WS_MAC) || defined(USE_OPEN_GL)
+            m_glWidget->setVisible(!show);
 #endif
-        m_effectView->setVisible(show);
+        }
+        m_effectWidget->setVisible(show);
+        m_effectWidget->getVisibilityAction()->setChecked(show);
         emit requestFrameForAnalysis(show);
         if (show) {
+            m_effectWidget->getScene()->slotZoomFit();
             render->doRefresh();
-            m_effectScene->slotZoomFit();
         }
     }
 }
 
-MonitorScene * Monitor::getEffectScene()
+MonitorEditWidget* Monitor::getEffectEdit()
 {
-    return m_effectScene;
+    return m_effectWidget;
 }
 
 bool Monitor::effectSceneDisplayed()
 {
-    return m_effectView->isVisible();
+    return m_effectWidget->isVisible();
+}
+
+void Monitor::slotSetVolume(int volume)
+{
+    KdenliveSettings::setVolume(volume);
+    KIcon icon;
+    if (volume == 0) icon = KIcon("audio-volume-muted");
+    else icon = KIcon("audio-volume-medium");
+    static_cast <QToolButton *>(m_volumeWidget)->setIcon(icon);
+    render->slotSetVolume(volume);
+}
+
+void Monitor::slotShowVolume()
+{
+    m_volumePopup->move(mapToGlobal(m_toolbar->geometry().topLeft()) + QPoint(mapToParent(m_volumeWidget->geometry().bottomLeft()).x(), -m_volumePopup->height()));
+    int vol = render->volume();
+    // Disable widget if we cannot get the volume
+    m_volumePopup->setEnabled(vol != -1);
+    m_audioSlider->blockSignals(true);
+    m_audioSlider->setValue(vol);
+    m_audioSlider->blockSignals(false);
+    m_volumePopup->show();
 }
 
 MonitorRefresh::MonitorRefresh(QWidget* parent) :
-        QWidget(parent),
-        m_renderer(NULL)
+    QWidget(parent)
+    , m_renderer(NULL)
 {
+    // MonitorRefresh is used as container for the SDL display (it's window id is passed to SDL)
     setAttribute(Qt::WA_PaintOnScreen);
     setAttribute(Qt::WA_OpaquePaintEvent);
+    setSizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::MinimumExpanding);
     //setAttribute(Qt::WA_NoSystemBackground);
 }
 
@@ -886,18 +1046,37 @@ void MonitorRefresh::setRenderer(Render* render)
 
 void MonitorRefresh::paintEvent(QPaintEvent *event)
 {
-    Q_UNUSED(event);
+    Q_UNUSED(event)
     if (m_renderer) m_renderer->doRefresh();
 }
 
 Overlay::Overlay(QWidget* parent) :
-        QLabel(parent)
+    QLabel(parent)
 {
-    setAttribute(Qt::WA_TransparentForMouseEvents);
-    //setAttribute(Qt::WA_OpaquePaintEvent);
-    //setAttribute(Qt::WA_NoSystemBackground);
+    //setAttribute(Qt::WA_TransparentForMouseEvents);
     setAutoFillBackground(true);
     setBackgroundRole(QPalette::Base);
+    setSizePolicy(QSizePolicy::Preferred, QSizePolicy::Preferred);
+    setCursor(Qt::PointingHandCursor);
+}
+
+// virtual
+void Overlay::mouseReleaseEvent ( QMouseEvent * event )
+{
+    event->accept();
+}
+
+// virtual
+void Overlay::mousePressEvent( QMouseEvent * event )
+{
+    event->accept();
+}
+
+// virtual
+void Overlay::mouseDoubleClickEvent ( QMouseEvent * event )
+{
+    emit editMarker();
+    event->accept();
 }
 
 void Overlay::setOverlayText(const QString &text, bool isZone)
@@ -914,4 +1093,117 @@ void Overlay::setOverlayText(const QString &text, bool isZone)
     update();
 }
 
+VideoContainer::VideoContainer(Monitor* parent) :
+    QFrame()
+    , m_monitor(parent)
+{
+    setFrameShape(QFrame::NoFrame);
+    setFocusPolicy(Qt::ClickFocus);
+    setSizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::MinimumExpanding);
+}
+
+// virtual
+void VideoContainer::mousePressEvent(QMouseEvent * event)
+{
+    if (m_monitor->underMouse()) event->setAccepted(false);
+}
+
+// virtual
+void VideoContainer::mouseReleaseEvent(QMouseEvent * event)
+{
+    if (m_monitor->underMouse()) event->setAccepted(false);
+    else {
+        if (m_monitor->isActive()) {
+            m_monitor->slotPlay();
+            event->accept();
+        }
+    }
+}
+
+// virtual
+void VideoContainer::mouseMoveEvent(QMouseEvent *event)
+{
+    if (m_monitor->underMouse()) event->setAccepted(false);
+}
+
+// virtual
+void VideoContainer::keyPressEvent(QKeyEvent *event)
+{
+    // Exit fullscreen with Esc key
+    if (event->key() == Qt::Key_Escape && isFullScreen()) {
+        switchFullScreen();
+        event->setAccepted(true);
+    } else event->setAccepted(false);
+}
+
+// virtual
+void VideoContainer::wheelEvent(QWheelEvent * event)
+{
+    if (m_monitor->underMouse()) event->setAccepted(false);
+    else {
+        m_monitor->slotMouseSeek(event->delta(), event->modifiers() == Qt::ControlModifier);
+        event->accept();
+    }
+}
+
+void VideoContainer::mouseDoubleClickEvent(QMouseEvent * event)
+{
+    Q_UNUSED(event)
+
+    if (!KdenliveSettings::openglmonitors())
+        switchFullScreen();
+}
+
+void VideoContainer::switchFullScreen()
+{
+    // TODO: disable screensaver?
+    Qt::WindowFlags flags = windowFlags();
+    if (!isFullScreen()) {
+        // Check if we ahave a multiple monitor setup
+        setUpdatesEnabled(false);
+#if QT_VERSION >= 0x040600
+        int monitors = QApplication::desktop()->screenCount();
+#else
+        int monitors = QApplication::desktop()->numScreens();
+#endif
+        if (monitors > 1) {
+            QRect screenres;
+            // Move monitor widget to the second screen (one screen for Kdenlive, the other one for the Monitor widget
+            int currentScreen = QApplication::desktop()->screenNumber(this);
+            if (currentScreen < monitors - 1)
+                screenres = QApplication::desktop()->screenGeometry(currentScreen + 1);
+            else
+                screenres = QApplication::desktop()->screenGeometry(currentScreen - 1);
+            move(QPoint(screenres.x(), screenres.y()));
+            resize(screenres.width(), screenres.height());
+        }
+
+        m_baseFlags = flags & (Qt::Window | Qt::SubWindow);
+        flags |= Qt::Window;
+        flags ^= Qt::SubWindow;
+        setWindowFlags(flags);
+#ifdef Q_WS_X11
+        // This works around a bug with Compiz
+        // as the window must be visible before we can set the state
+        show();
+        raise();
+        setWindowState(windowState() | Qt::WindowFullScreen);   // set
+#else
+        setWindowState(windowState() | Qt::WindowFullScreen);   // set
+        setUpdatesEnabled(true);
+        show();
+#endif
+    } else {
+        setUpdatesEnabled(false);
+        flags ^= (Qt::Window | Qt::SubWindow); //clear the flags...
+        flags |= m_baseFlags; //then we reset the flags (window and subwindow)
+        setWindowFlags(flags);
+        setWindowState(windowState()  ^ Qt::WindowFullScreen);   // reset
+        setUpdatesEnabled(true);
+        show();
+    }
+    m_monitor->pause();
+}
+
+
 #include "monitor.moc"
