@@ -17,53 +17,93 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA          *
  ***************************************************************************/
 
-
 #ifndef MONITOR_H
 #define MONITOR_H
 
+
+#include "gentime.h"
+#include "timecodedisplay.h"
+#if defined(Q_WS_MAC) || defined(USE_OPEN_GL)
+#include "videoglwidget.h"
+#endif
+
 #include <QLabel>
+#include <QDomElement>
+#include <QToolBar>
+#include <QSlider>
 
 #include <KIcon>
 #include <KAction>
 #include <KRestrictedLine>
-#include <QDomElement>
 
-#include "gentime.h"
-#include "ui_monitor_ui.h"
-#include "timecodedisplay.h"
-#ifdef Q_WS_MAC
-#include "videoglwidget.h"
-#endif
 
 class MonitorManager;
 class Render;
 class SmallRuler;
 class DocClipBase;
-class MonitorScene;
-class QGraphicsView;
-class QGraphicsPixmapItem;
+class AbstractClipItem;
+class Transition;
+class ClipItem;
+class MonitorEditWidget;
+
+class Monitor;
+
+class VideoContainer : public QFrame
+{
+    Q_OBJECT
+public:
+    VideoContainer(Monitor *parent = 0);
+    void switchFullScreen();
+
+protected:
+    virtual void mouseDoubleClickEvent(QMouseEvent * event);
+    virtual void mousePressEvent(QMouseEvent * event);
+    virtual void mouseReleaseEvent(QMouseEvent *event);
+    virtual void mouseMoveEvent(QMouseEvent *event);
+    void keyPressEvent(QKeyEvent *event);
+    virtual void wheelEvent(QWheelEvent * event);
+
+private:
+    Qt::WindowFlags m_baseFlags;
+    Monitor *m_monitor;
+};
 
 class MonitorRefresh : public QWidget
 {
     Q_OBJECT
 public:
     MonitorRefresh(QWidget *parent = 0);
-    virtual void paintEvent(QPaintEvent *event);
     void setRenderer(Render* render);
 
+protected:
+    virtual void paintEvent(QPaintEvent *event);
+
 private:
     Render *m_renderer;
+
+signals:
+    void switchFullScreen();
+    void switchPlay();
+    void mouseSeek(int, bool);
 };
 
 class Overlay : public QLabel
 {
     Q_OBJECT
 public:
-    Overlay(QWidget* parent);
+    Overlay(QWidget* parent = 0);
     void setOverlayText(const QString &, bool isZone = true);
 
 private:
     bool m_isZone;
+
+protected:
+    virtual void mouseDoubleClickEvent ( QMouseEvent * event );
+    virtual void mousePressEvent ( QMouseEvent * event );
+    virtual void mouseReleaseEvent ( QMouseEvent * event );
+    
+signals:
+    void editMarker();
 };
 
 class Monitor : public QWidget
@@ -79,14 +119,16 @@ public:
     void resetSize();
     bool isActive() const;
     void pause();
-    void setupMenu(QMenu *goMenu, QAction *playZone, QAction *loopZone, QMenu *markerMenu = NULL);
+    void setupMenu(QMenu *goMenu, QAction *playZone, QAction *loopZone, QMenu *markerMenu = NULL, QAction *loopClip = NULL);
     const QString sceneList();
     DocClipBase *activeClip();
     GenTime position();
     void checkOverlay();
     void updateTimecodeFormat();
     void updateMarkers(DocClipBase *source);
-    MonitorScene *getEffectScene();
+    MonitorEditWidget *getEffectEdit();
+    QWidget *container();
+    QFrame *m_volumePopup;
 
 protected:
     virtual void mousePressEvent(QMouseEvent * event);
@@ -107,7 +149,6 @@ protected:
     //virtual void paintEvent(QPaintEvent * event);
 
 private:
-    Ui::Monitor_UI m_ui;
     QString m_name;
     MonitorManager *m_monitorManager;
     DocClipBase *m_currentClip;
@@ -122,17 +163,31 @@ private:
     KIcon m_pauseIcon;
     TimecodeDisplay *m_timePos;
     QAction *m_playAction;
+    /** Has to be available so we can enable and disable it. */
+    QAction *m_loopClipAction;
     QMenu *m_contextMenu;
     QMenu *m_configMenu;
     QMenu *m_playMenu;
     QMenu *m_markerMenu;
     QPoint m_DragStartPosition;
-    MonitorScene *m_effectScene;
-    QGraphicsView *m_effectView;
-#ifdef Q_WS_MAC
+    MonitorEditWidget *m_effectWidget;
+    VideoContainer *m_videoBox;
+    /** Selected clip/transition in timeline. Used for looping it. */
+    AbstractClipItem *m_selectedClip;
+    /** true if selected clip is transition, false = selected clip is clip.
+     *  Necessary because sometimes we get two signals, e.g. we get a clip and we get selected transition = NULL. */
+    bool m_loopClipTransition;
+#if defined(Q_WS_MAC) || defined(USE_OPEN_GL)
     VideoGLWidget *m_glWidget;
+    bool createOpenGlWidget(QWidget *parent, const QString profile);
 #endif
+
     GenTime getSnapForPos(bool previous);
+    Qt::WindowFlags m_baseFlags;
+    QToolBar *m_toolbar;
+    QWidget *m_volumeWidget;
+    QSlider *m_audioSlider;
+    QAction *m_editMarker;
 
 private slots:
     void seekCursor(int pos);
@@ -147,12 +202,15 @@ private slots:
     void slotSwitchMonitorInfo(bool show);
     void slotSwitchDropFrames(bool show);
     void slotGoToMarker(QAction *action);
+    void slotSetVolume(int volume);
+    void slotShowVolume();
+    void slotEditMarker();
 
 public slots:
     void slotOpenFile(const QString &);
     void slotSetXml(DocClipBase *clip, QPoint zone = QPoint(), const int position = -1);
-    void initMonitor();
-    void refreshMonitor(bool visible = true);
+    void refreshMonitor(bool visible);
+    void refreshMonitor();
     void slotSeek(int pos);
     void stop();
     void start();
@@ -160,6 +218,8 @@ public slots:
     void slotPlay();
     void slotPlayZone();
     void slotLoopZone();
+    /** @brief Loops the selected item (clip or transition). */
+    void slotLoopClip();
     void slotForward(double speed = 0);
     void slotRewind(double speed = 0);
     void slotRewindOneFrame(int diff = 1);
@@ -180,14 +240,21 @@ public slots:
     void slotEffectScene(bool show = true);
     bool effectSceneDisplayed();
 
+    /** @brief Sets m_selectedClip to @param item. Used for looping it. */
+    void slotSetSelectedClip(AbstractClipItem *item);
+    void slotSetSelectedClip(ClipItem *item);
+    void slotSetSelectedClip(Transition *item);
+    void slotMouseSeek(int eventDelta, bool fast);
+    void slotSwitchFullScreen();
+
 signals:
     void renderPosition(int);
     void durationChanged(int);
-    void refreshClipThumbnail(const QString &);
+    void refreshClipThumbnail(const QString &, bool);
     void adjustMonitorSize();
     void zoneUpdated(QPoint);
     void saveZone(Render *, QPoint);
-    /** @brief  Editing transitions / effects over the monitor requires thr renderer to send frames as QImage.
+    /** @brief  Editing transitions / effects over the monitor requires the renderer to send frames as QImage.
      *      This causes a major slowdown, so we only enable it if required */
     void requestFrameForAnalysis(bool);
 };
