@@ -19,6 +19,7 @@
 
 
 #include "monitormanager.h"
+#include "renderer.h"
 #include "kdenlivesettings.h"
 
 #include <mlt++/Mlt.h>
@@ -86,6 +87,11 @@ void MonitorManager::slotPlay()
     else m_projectMonitor->slotPlay();
 }
 
+void MonitorManager::slotPause()
+{
+  stopActiveMonitor();
+}
+
 void MonitorManager::slotPlayZone()
 {
     if (m_clipMonitor->isActive()) m_clipMonitor->slotPlayZone();
@@ -169,5 +175,21 @@ void MonitorManager::slotResetProfiles()
     activateMonitor(active);
 }
 
+void MonitorManager::slotRefreshCurrentMonitor()
+{
+    if (m_clipMonitor->isActive()) m_clipMonitor->refreshMonitor();
+    else m_projectMonitor->refreshMonitor();
+}
+
+void MonitorManager::slotUpdateAudioMonitoring()
+{
+    // if(...) added since they are 0x0 when the config wizard is running! --Granjow
+    if (m_clipMonitor) {
+        m_clipMonitor->render->analyseAudio = KdenliveSettings::monitor_audio();
+    }
+    if (m_projectMonitor) {
+        m_projectMonitor->render->analyseAudio = KdenliveSettings::monitor_audio();
+    }
+}
 
 #include "monitormanager.moc"
