@@ -43,6 +43,7 @@ public slots:
      * @param name name of the monitor to activate */
     void activateMonitor(QString name = QString());
     void slotPlay();
+    void slotPause();
     void slotPlayZone();
     void slotLoopZone();
     void slotRewind(double speed = 0);
@@ -59,6 +60,10 @@ public slots:
      * @ref activateMonitor
      * @param activateClip whether to activate the clip monitor */
     void slotSwitchMonitors(bool activateClip);
+    void slotUpdateAudioMonitoring();
+
+private slots:
+    void slotRefreshCurrentMonitor();
 
 private:
     Monitor *m_clipMonitor;
