@@ -28,36 +28,31 @@
 #include <KIcon>
 
 const int DurationRole = Qt::UserRole + 1;
+const int ProxyRole = Qt::UserRole + 5;
 const int itemHeight = 38;
 
 ProjectItem::ProjectItem(QTreeWidget * parent, DocClipBase *clip) :
-        QTreeWidgetItem(parent, PROJECTCLIPTYPE)
+        QTreeWidgetItem(parent, PROJECTCLIPTYPE),
+        m_clip(clip),
+        m_clipId(clip->getId())
 {
-    setSizeHint(0, QSize(itemHeight * 3, itemHeight));
-    if (clip->isPlaceHolder()) setFlags(Qt::ItemIsSelectable | Qt::ItemIsEnabled | Qt::ItemIsDropEnabled);
-    else setFlags(Qt::ItemIsSelectable | Qt::ItemIsDragEnabled | Qt::ItemIsEnabled | Qt::ItemIsEditable | Qt::ItemIsDropEnabled);
-    m_clip = clip;
-    m_clipId = clip->getId();
-    QString name = m_clip->getProperty("name");
-    if (name.isEmpty()) name = KUrl(m_clip->getProperty("resource")).fileName();
-    m_clipType = (CLIPTYPE) m_clip->getProperty("type").toInt();
-    if (m_clipType != UNKNOWN) slotSetToolTip();
-    setText(0, name);
-    setText(1, m_clip->description());
-    GenTime duration = m_clip->duration();
-    if (duration != GenTime()) setData(0, DurationRole, Timecode::getEasyTimecode(duration, KdenliveSettings::project_fps()));
-    //setFlags(Qt::NoItemFlags);
-    //kDebug() << "Constructed with clipId: " << m_clipId;
+    buildItem();
 }
 
 ProjectItem::ProjectItem(QTreeWidgetItem * parent, DocClipBase *clip) :
-        QTreeWidgetItem(parent, PROJECTCLIPTYPE)
+        QTreeWidgetItem(parent, PROJECTCLIPTYPE),
+        m_clip(clip),
+        m_clipId(clip->getId())
+        
+{
+    buildItem();
+}
+
+void ProjectItem::buildItem()
 {
     setSizeHint(0, QSize(itemHeight * 3, itemHeight));
-    if (clip->isPlaceHolder()) setFlags(Qt::ItemIsSelectable | Qt::ItemIsEnabled | Qt::ItemIsDropEnabled);
+    if (m_clip->isPlaceHolder()) setFlags(Qt::ItemIsSelectable | Qt::ItemIsEnabled | Qt::ItemIsDropEnabled);
     else setFlags(Qt::ItemIsSelectable | Qt::ItemIsDragEnabled | Qt::ItemIsEnabled | Qt::ItemIsEditable | Qt::ItemIsDropEnabled);
-    m_clip = clip;
-    m_clipId = clip->getId();
     QString name = m_clip->getProperty("name");
     if (name.isEmpty()) name = KUrl(m_clip->getProperty("resource")).fileName();
     m_clipType = (CLIPTYPE) m_clip->getProperty("type").toInt();
@@ -65,11 +60,8 @@ ProjectItem::ProjectItem(QTreeWidgetItem * parent, DocClipBase *clip) :
     setText(1, m_clip->description());
     GenTime duration = m_clip->duration();
     if (duration != GenTime()) setData(0, DurationRole, Timecode::getEasyTimecode(duration, KdenliveSettings::project_fps()));
-    //setFlags(Qt::NoItemFlags);
-    //kDebug() << "Constructed with clipId: " << m_clipId;
 }
 
-
 ProjectItem::~ProjectItem()
 {
 }
@@ -238,3 +230,27 @@ void ProjectItem::setProperties(const QMap < QString, QString > &attributes, con
     }
 }
 
+void ProjectItem::setProxyStatus(PROXYSTATUS status)
+{
+    setData(0, ProxyRole, status);
+}
+
+bool ProjectItem::hasProxy() const
+{
+    if (m_clip == NULL) return false;
+    if (m_clip->getProperty("proxy").isEmpty() || m_clip->getProperty("proxy") == "-" || data(0, ProxyRole).toInt() == PROXYCRASHED) return false;
+    return true;
+}
+
+bool ProjectItem::isProxyReady() const
+{
+     return (data(0, ProxyRole).toInt() == PROXYDONE);
+}
+
+bool ProjectItem::isProxyRunning() const
+{
+    PROXYSTATUS s = (PROXYSTATUS) data(0, ProxyRole).toInt();
+    if (s == PROXYWAITING || s == CREATINGPROXY) return true;
+    return false;
+}
+
