@@ -24,6 +24,7 @@
 #include <QTreeWidgetItem>
 #include <QTreeWidget>
 #include <QDomElement>
+#include <QProcess>
 
 #include <KUrl>
 
@@ -62,6 +63,14 @@ public:
     QString getClipHash() const;
     static int itemDefaultHeight();
     void slotSetToolTip();
+    /** \brief Set the status of proxy clip creation. 0 = no proxy, 1 = creating proxy, 2 = proxy created. */
+    void setProxyStatus(PROXYSTATUS status);
+    /** \brief Returns the proxy status for this clip (true means there is a proxy clip). */
+    bool hasProxy() const;
+    /** \brief Returns true if the proxy for this clip is ready. */
+    bool isProxyReady() const;
+    /** \brief Returns true if we are currently creating the proxy for this clip. */
+    bool isProxyRunning() const;
 
     virtual bool operator<(const QTreeWidgetItem &other)const {
         int column = treeWidget()->sortColumn();
@@ -72,8 +81,11 @@ public:
 
 private:
     CLIPTYPE m_clipType;
-    QString m_clipId;
     DocClipBase *m_clip;
+    QString m_clipId;
+
+    void buildItem();
+
 };
 
 #endif
