@@ -30,6 +30,7 @@
 #include <QUndoStack>
 #include <QTimer>
 #include <QApplication>
+#include <QFuture>
 
 #include <KTreeWidgetSearchLine>
 #include <KUrl>
@@ -107,7 +108,44 @@ public:
             int usage = index.data(UsageRole).toInt();
             if (usage != 0) subText.append(QString(" (%1)").arg(usage));
             if (option.state & (QStyle::State_Selected)) painter->setPen(option.palette.color(QPalette::Mid));
-            painter->drawText(r2, Qt::AlignLeft | Qt::AlignVCenter , subText);
+            QRectF bounding;
+            painter->drawText(r2, Qt::AlignLeft | Qt::AlignVCenter , subText, &bounding);
+            
+            int proxy = index.data(Qt::UserRole + 5).toInt();
+            if (proxy > 0) {
+                QRectF txtBounding;
+                QString proxyText;
+                QBrush brush;
+                QColor color;
+                if (proxy == PROXYDONE) {
+                    proxyText = i18n("Proxy");
+                    brush = option.palette.mid();
+                    color = option.palette.color(QPalette::WindowText);
+                }
+                else {
+                    switch (proxy)  {
+                        case CREATINGPROXY:
+                            proxyText = i18n("Generating proxy ...");
+                            break;
+                        case PROXYWAITING:
+                            proxyText = i18n("Waiting proxy ...");
+                            break;
+                        case PROXYCRASHED:
+                        default:
+                            proxyText = i18n("Proxy crashed");
+                    }
+                    brush = option.palette.highlight();
+                    color = option.palette.color(QPalette::HighlightedText);
+                }
+               
+                txtBounding = painter->boundingRect(r2, Qt::AlignRight | Qt::AlignVCenter, " " + proxyText + " ");
+                painter->setPen(Qt::NoPen);
+                painter->setBrush(brush);
+                painter->drawRoundedRect(txtBounding, 2, 2);
+                painter->setPen(option.palette.highlightedText().color());
+                painter->drawText(txtBounding, Qt::AlignHCenter | Qt::AlignVCenter , proxyText);
+            }
+            
             painter->restore();
         } else if (index.column() == 2 && KdenliveSettings::activate_nepomuk()) {
             if (index.data().toString().isEmpty()) {
@@ -161,18 +199,34 @@ public:
 
     /** @brief Returns a string list of all supported mime extensions. */
     static QString getExtensions();
+    /** @brief Returns a list of urls containing original and proxy urls. */
+    QMap <QString, QString> getProxies();
+    /** @brief Enable / disable proxies. */
+    void updateProxyConfig();
+    /** @brief Get a property from the document. */
+    QString getDocumentProperty(const QString &key) const;
+    
+    /** @brief Does this project allow proxies. */
+    bool useProxy() const;
+    /** @brief Should we automatically create proxy clips for newly added clips. */
+    bool generateProxy() const;
+    /** @brief Should we automatically create proxy clips for newly added clips. */
+    bool generateImageProxy() const;
+    /** @brief Returns a list of the expanded folder ids. */
+    QStringList expandedFolders() const;
 
 public slots:
     void setDocument(KdenliveDoc *doc);
     void updateAllClips();
     void slotReplyGetImage(const QString &clipId, const QPixmap &pix);
-    void slotReplyGetFileProperties(const QString &clipId, Mlt::Producer *producer, const QMap < QString, QString > &properties, const QMap < QString, QString > &metadata, bool replace);
+    void slotReplyGetFileProperties(const QString &clipId, Mlt::Producer *producer, const QMap < QString, QString > &properties, const QMap < QString, QString > &metadata, bool replace, bool selectClip);
     void slotAddClip(DocClipBase *clip, bool getProperties);
     void slotDeleteClip(const QString &clipId);
     void slotUpdateClip(const QString &id);
     void slotRefreshClipThumbnail(const QString &clipId, bool update = true);
     void slotRefreshClipThumbnail(QTreeWidgetItem *item, bool update = true);
     void slotRemoveInvalidClip(const QString &id, bool replace);
+    void slotRemoveInvalidProxy(const QString &id, bool durationError);
     void slotSelectClip(const QString &ix);
 
     /** @brief Prepares removing the selected items. */
@@ -200,26 +254,33 @@ private:
     Render *m_render;
     Timecode m_timecode;
     double m_fps;
-    QToolBar *m_toolbar;
-    QTimer m_queueTimer;
     QMenu *m_menu;
+    QFuture<void> m_queueRunner;
     QUndoStack *m_commandStack;
     ProjectItem *getItemById(const QString &id);
     QTreeWidgetItem *getAnyItemById(const QString &id);
     FolderProjectItem *getFolderItemById(const QString &id);
-    QAction *m_editAction;
-    QAction *m_deleteAction;
     QAction *m_openAction;
     QAction *m_reloadAction;
     QMenu *m_transcodeAction;
     KdenliveDoc *m_doc;
     ItemDelegate *m_listViewDelegate;
+    /** @brief True if we have not yet finished opening the document. */
     bool m_refreshed;
     QToolButton *m_addButton;
+    QToolButton *m_deleteButton;
+    QToolButton *m_editButton;
     QMap <QString, QDomElement> m_infoQueue;
     QMap <QString, QDomElement> m_producerQueue;
     void requestClipInfo(const QDomElement xml, const QString id);
     QList <QString> m_thumbnailQueue;
+    QAction *m_proxyAction;
+    QStringList m_processingClips;
+    /** @brief Holds a list of ids for the clips that need to be proxied. */
+    QStringList m_proxyList;
+    /** @brief Holds a list of proxy clip that should be aborted. */
+    QStringList m_abortProxyId;
+    
     void requestClipThumbnail(const QString id);
 
     /** @brief Creates an EditFolderCommand to change the name of an folder item. */
@@ -232,10 +293,20 @@ private:
 
     /** @brief Enables and disables transcode actions based on the selected clip's type. */
     void adjustTranscodeActions(ProjectItem *clip) const;
+    /** @brief Enables and disables proxy action based on the selected clip. */
+    void adjustProxyActions(ProjectItem *clip) const;
 
     /** @brief Sets the buttons enabled/disabled according to selected item. */
     void updateButtons() const;
 
+    /** @brief Set the Proxy status on a clip. 
+     * @param item The clip item to set status
+     * @param status The proxy status (see definitions.h) */
+    void setProxyStatus(const QString id, PROXYSTATUS status);
+    void setProxyStatus(ProjectItem *item, PROXYSTATUS status);
+
+    void monitorItemEditing(bool enable);
+
 private slots:
     void slotClipSelected();
     void slotAddSlideshowClip();
@@ -261,11 +332,24 @@ private slots:
     void slotModifiedClip(const QString &id);
     void slotMissingClip(const QString &id);
     void slotAvailableClip(const QString &id);
-    //void slotShowMenu(const QPoint &pos);
+    /** @brief Try to find a matching profile for given item. */
+    bool adjustProjectProfileToItem(ProjectItem *item = NULL);
+    /** @brief Add a sequence from the stopmotion widget. */
+    void slotAddOrUpdateSequence(const QString frameName);
+    /** @brief A proxy clip was created, update display. */
+    void slotGotProxy(const QString &id);
+    /** @brief Enable / disable proxy for current clip. */
+    void slotProxyCurrentItem(bool doProxy);
+    /** @brief Put clip in the proxy waiting list. */
+    void slotCreateProxy(const QString id, bool createProducer = true);
+    /** @brief Stop creation of this clip's proxy. */
+    void slotAbortProxy(const QString id);
+    /** @brief Start creation of proxy clip. */
+    void slotGenerateProxy(const QString id);
 
 signals:
     void clipSelected(DocClipBase *, QPoint zone = QPoint());
-    void getFileProperties(const QDomElement, const QString &, int pixHeight, bool);
+    void getFileProperties(const QDomElement, const QString &, int pixHeight, bool, bool);
     void receivedClipDuration(const QString &);
     void showClipProperties(DocClipBase *);
     void showClipProperties(QList <DocClipBase *>, QMap<QString, QString> commonproperties);
@@ -274,10 +358,17 @@ signals:
     void displayMessage(const QString, int progress);
     void clipNameChanged(const QString, const QString);
     void clipNeedsReload(const QString&, bool);
-    void refreshClip();
+    /** @brief A property affecting display was changed, so we need to update monitors and thumbnails
+     *  @param id: The clip's id string
+     *  @param resetThumbs Should we recreate the timeline thumbnails. */
+    void refreshClip(const QString &id, bool resetThumbs);
     void updateRenderStatus();
     void deleteProjectClips(QStringList ids, QMap <QString, QString> folderids);
     void findInTimeline(const QString &clipId);
+    /** @brief Request a profile change for current document. */
+    void updateProfile(const QString &);
+    void processNextThumbnail();
 };
 
 #endif
+
