@@ -38,6 +38,13 @@ public:
     QPoint tracks();
     bool enableVideoThumbs() const;
     bool enableAudioThumbs() const;
+    bool useProxy() const;
+    bool generateProxy() const;
+    int proxyMinSize() const;
+    bool generateImageProxy() const;
+    int proxyImageMinSize() const;
+    QString proxyParams() const;
+    QString proxyExtension() const;
     static QStringList extractPlaylistUrls(QString path);
     static QStringList extractSlideshowUrls(KUrl url);
 
@@ -49,7 +56,10 @@ private slots:
     void slotUpdateButton(const QString &path);
     void slotUpdateFiles(bool cacheOnly = false);
     void slotClearCache();
+    void slotDeleteProxies();
     void slotDeleteUnused();
+    /** @brief Export project data to text file. */
+    void slotExportToText();
 
 private:
     QPushButton *m_buttonOk;
