@@ -2,8 +2,9 @@
                          krender.h  -  description
                             -------------------
    begin                : Fri Nov 22 2002
-   copyright            : (C) 2002 by Jason Wood
-   email                : jasonwood@blueyonder.co.uk
+   copyright            : (C) 2002 by Jason Wood (jasonwood@blueyonder.co.uk)
+   copyright            : (C) 2010 by Jean-Baptiste Mardelle (jb@kdenlive.org)
+
 ***************************************************************************/
 
 /***************************************************************************
@@ -17,7 +18,6 @@
 
 /**
  * @class Render
- * @author Jason Wood
  * @brief Client side of the interface to a renderer.
  *
  * From Kdenlive's point of view, you treat the Render object as the renderer,
@@ -31,6 +31,7 @@
 
 #include "gentime.h"
 #include "definitions.h"
+#include "mlt/framework/mlt_types.h"
 
 #include <kurl.h>
 
@@ -40,9 +41,6 @@
 #include <QList>
 #include <QEvent>
 
-#ifdef Q_WS_MAC
-#include "videoglwidget.h"
-#endif
 
 class Render;
 
@@ -82,43 +80,40 @@ Q_OBJECT public:
     enum FailStates { OK = 0,
                       APP_NOEXIST
                     };
+    /** @brief Build a MLT Renderer
+     *  @param rendererName A unique identifier for this renderer
+     *  @param winid The parent widget identifier (required for SDL display). Set to 0 for OpenGL rendering
+     *  @param profile The MLT profile used for the renderer (default one will be used if empty). */
+    Render(const QString & rendererName, int winid, QString profile = QString(), QWidget *parent = 0);
 
-    Render(const QString & rendererName, int winid, int extid, QString profile = QString(), QWidget *parent = 0);
+    /** @brief Destroy the MLT Renderer. */
     ~Render();
 
     /** @brief Seeks the renderer clip to the given time. */
     void seek(GenTime time);
+    void seek(int time);
     void seekToFrame(int pos);
     void seekToFrameDiff(int diff);
     int m_isBlocked;
 
-    //static QPixmap getVideoThumbnail(char *profile, QString file, int frame, int width, int height);
     QPixmap getImageThumbnail(KUrl url, int width, int height);
 
-    /* Return thumbnail for color clip
-    void getImage(int id, QString color, QPoint size);*/
-
-    // static QPixmap frameThumbnail(Mlt::Frame *frame, int width, int height, bool border = false);
-
-    /* Return thumbnail for image clip
-    void getImage(KUrl url, QPoint size);*/
-
-    /* Requests a particular frame from the given file.
-     *
-     * The pixmap will be returned by emitting the replyGetImage() signal.
-    void getImage(KUrl url, int frame, QPoint size);*/
-
+    /** @brief Sets the current MLT producer playlist.
+     * @param list The xml describing the playlist
+     * @param position (optional) time to seek to */
     int setSceneList(QDomDocument list, int position = 0);
 
-    /** @brief Sets the current scene list.
-     * @param list new scene list
+    /** @brief Sets the current MLT producer playlist.
+     * @param list new playlist
      * @param position (optional) time to seek to
      * @return 0 when it has success, different from 0 otherwise
      *
-     * Creates the producer from the MLT XML QDomDocument. Wraps the VEML
-     * command of the same name. */
+     * Creates the producer from the text playlist. */
     int setSceneList(QString playlist, int position = 0);
     int setProducer(Mlt::Producer *producer, int position);
+
+    /** @brief Get the current MLT producer playlist.
+     * @return A string describing the playlist */
     const QString sceneList();
     bool saveSceneList(QString path, QDomElement kdenliveData = QDomElement());
 
@@ -126,8 +121,7 @@ Q_OBJECT public:
      * @param speed speed to play the scene to
      *
      * The speed is relative to normal playback, e.g. 1.0 is normal speed, 0.0
-     * is paused, -1.0 means play backwards. It does not specify start/stop
-     * times for playback. Wraps the VEML command of the same name. */
+     * is paused, -1.0 means play backwards. It does not specify start/stop */
     void play(double speed);
     void switchPlay();
     void pause();
@@ -135,14 +129,12 @@ Q_OBJECT public:
     /** @brief Stops playing.
      * @param startTime time to seek to */
     void stop(const GenTime & startTime);
-    void setVolume(double volume);
+    int volume() const;
 
-    QImage extractFrame(int frame_position, int width = -1, int height = -1);
+    QImage extractFrame(int frame_position, QString path = QString(), int width = -1, int height = -1);
 
     /** @brief Plays the scene starting from a specific time.
-     * @param startTime time to start playing the scene from
-     *
-     * Wraps the VEML command of the same name. */
+     * @param startTime time to start playing the scene from */
     void play(const GenTime & startTime);
     void playZone(const GenTime & startTime, const GenTime & stopTime);
     void loopZone(const GenTime & startTime, const GenTime & stopTime);
@@ -187,6 +179,8 @@ Q_OBJECT public:
 
     /** @brief Returns display aspect ratio. */
     double dar() const;
+    /** @brief Returns sample aspect ratio. */
+    double sar() const;
 
     /*
      * Playlist manipulation.
@@ -197,7 +191,10 @@ Q_OBJECT public:
     void mltCutClip(int track, GenTime position);
     void mltInsertSpace(QMap <int, int> trackClipStartList, QMap <int, int> trackTransitionStartList, int track, const GenTime duration, const GenTime timeOffset);
     int mltGetSpaceLength(const GenTime pos, int track, bool fromBlankStart);
+
+    /** @brief Returns the duration/length of @param track as reported by the track producer. */
     int mltTrackDuration(int track);
+
     bool mltResizeClipEnd(ItemInfo info, GenTime clipDuration);
     bool mltResizeClipStart(ItemInfo info, GenTime diff);
     bool mltResizeClipCrop(ItemInfo info, GenTime diff);
@@ -259,9 +256,11 @@ Q_OBJECT public:
     void updatePreviewSettings();
     void setDropFrames(bool show);
     QString updateSceneListFps(double current_fps, double new_fps, QString scene);
-#ifdef Q_WS_MAC
     void showFrame(Mlt::Frame&);
-#endif
+
+    void showAudio(Mlt::Frame&);
+    /** @brief This property is used to decide if the renderer should send audio data for monitoring. */
+    bool analyseAudio;
     /** @brief This property is used to decide if the renderer should convert it's frames to QImage for use in other Kdenlive widgets. */
     bool sendFrameForAnalysis;
     QList <int> checkTrackSequence(int);
@@ -279,6 +278,7 @@ private:
     Mlt::Profile *m_mltProfile;
     double m_framePosition;
     double m_fps;
+    bool m_externalConsumer;
 
     /** @brief True if we are playing a zone.
      *
@@ -300,17 +300,23 @@ private:
     /** @brief A human-readable description of this renderer. */
     int m_winid;
 
-#ifdef Q_WS_MAC
-    VideoGLWidget *m_glWidget;
-#endif
     void closeMlt();
     void mltCheckLength(Mlt::Tractor *tractor);
     void mltPasteEffects(Mlt::Producer *source, Mlt::Producer *dest);
     QMap<QString, QString> mltGetTransitionParamsFromXml(QDomElement xml);
     QMap<QString, Mlt::Producer *> m_slowmotionProducers;
+
+    /** @brief Build the MLT Consumer object with initial settings.
+     *  @param profileName The MLT profile to use for the consumer */
     void buildConsumer(const QString profileName);
     void resetZoneMode();
     void fillSlowMotionProducers();
+    /** @brief Get the track number of the lowest audible (non muted) audio track
+     *  @param return The track number */
+    int getLowestNonMutedAudioTrack(Mlt::Tractor tractor);
+
+    /** @brief Make sure our audio mixing transitions are applied to the lowest track */
+    void fixAudioMixing(Mlt::Tractor tractor);
 
 private slots:
 
@@ -323,7 +329,7 @@ private slots:
 signals:
 
     /** @brief The renderer received a reply to a getFileProperties request. */
-    void replyGetFileProperties(const QString &clipId, Mlt::Producer*, const QMap < QString, QString > &, const QMap < QString, QString > &, bool);
+    void replyGetFileProperties(const QString &clipId, Mlt::Producer*, const QMap < QString, QString > &, const QMap < QString, QString > &, bool, bool);
 
     /** @brief The renderer received a reply to a getImage request. */
     void replyGetImage(const QString &, const QPixmap &);
@@ -337,28 +343,29 @@ signals:
     /** @brief The renderer started rendering. */
     void rendering(const GenTime &);
 
-    /** @brief The rendering has finished.
-        @see consumer_frame_show
-        This signal seems to be useless; use renderPosition(int) instead --Granjow */
-    void renderFinished();
-
-    /* @brief The current seek position has been changed by the renderer.
-    void positionChanged(const GenTime &);*/
-
     /** @brief An error occurred within this renderer. */
     void error(const QString &, const QString &);
     void durationChanged(int);
     void rendererPosition(int);
     void rendererStopped(int);
+    /** @brief The clip is not valid, should be removed from project. */
     void removeInvalidClip(const QString &, bool replaceProducer);
+    /** @brief The proxy is not valid, should be deleted.
+     *  @param id The original clip's id
+     *  @param durationError Should be set to true if the proxy failed because it has not same length as original clip
+     */
+    void removeInvalidProxy(const QString &id, bool durationError);
     void refreshDocumentProducers();
 
     /** @brief A frame's image has to be shown.
      *
      * Used in Mac OS X. */
     void showImageSignal(QImage);
+    void showAudioSignal(const QByteArray);
     /** @brief The renderer refreshed the current frame, but no seeking was done. */
     void frameUpdated(QImage);
+    /** @brief This signal contains the audio of the current frame. */
+    void audioSamplesSignal(const QVector<int16_t>&, int freq, int num_channels, int num_samples);
 
 public slots:
 
@@ -373,16 +380,20 @@ public slots:
     bool isValid(KUrl url);
 
     /** @brief Requests the file properties for the specified URL.
-     *
+        @param xml The xml parameters for the clip
+        @param clipId The clip Id string
+        @param imageHeight The height (in pixels) of the returned thumbnail (height of a treewidgetitem in projectlist)
+        @param replaceProducer If true, the MLT producer will be recreated
+        @param selectClip If true, clip item will be selected in project view
      * Upon return, the result will be emitted via replyGetFileProperties().
      * Wraps the VEML command of the same name. */
-    void getFileProperties(const QDomElement xml, const QString &clipId, int imageHeight, bool replaceProducer = true);
+    void getFileProperties(const QDomElement xml, const QString &clipId, int imageHeight, bool replaceProducer = true, bool selectClip = false);
 
     void exportFileToFirewire(QString srcFileName, int port, GenTime startTime, GenTime endTime);
-    static char *decodedString(QString str);
     void mltSavePlaylist();
     void slotSplitView(bool doit);
     void slotSwitchFullscreen();
+    void slotSetVolume(int volume);
 };
 
 #endif
