@@ -109,7 +109,7 @@ class RenderWidget : public QDialog
     Q_OBJECT
 
 public:
-    explicit RenderWidget(const QString &projectfolder, QWidget * parent = 0);
+    explicit RenderWidget(const QString &projectfolder, bool enableProxy, QWidget * parent = 0);
     virtual ~RenderWidget();
     void setGuides(QDomElement guidesxml, double duration);
     void focusFirstVisibleItem();
@@ -127,6 +127,10 @@ public:
     bool automaticAudioExport() const;
     /** @brief Returns true if user wants audio export. */
     bool selectedAudioExport() const;
+    /** @brief Show / hide proxy settings. */
+    void updateProxyConfig(bool enable);
+    /** @brief Should we render using proxy clips. */
+    bool proxyRendering();
 
 public slots:
     void slotExport(bool scriptExport, int zoneIn, int zoneOut, const QString &playlistPath, const QString &scriptPath, bool exportAudio);
@@ -160,6 +164,7 @@ private slots:
     void slotPlayRendering(QTreeWidgetItem *item, int);
     void slotStartCurrentJob();
     void slotCopyToFavorites();
+    void slotUpdateEncodeThreads(int);
     void slotUpdateRescaleHeight(int);
     void slotUpdateRescaleWidth(int);
     void slotSwitchAspectRatio();
