@@ -17,10 +17,13 @@
 #ifndef TIMECODE_H
 #define TIMECODE_H
 
-#include <qstring.h>
+#include <QString>
 
 #include "gentime.h"
 
+class QValidator;
+class QRegExpValidator;
+
 /**
 Handles the conversion of a GenTime into a nicely formatted string, taking into account things such as drop frame if necessary. Handles multiple formats, such as HH:MM:SS:FF, HH:MM:SS:F, All Frames, All Seconds, etc.
 
@@ -31,16 +34,12 @@ class Timecode
 public:
     enum Formats { HH_MM_SS_FF, HH_MM_SS_HH, Frames, Seconds };
 
-    explicit Timecode(Formats format = HH_MM_SS_FF, double framesPerSecond =
-                          25, bool dropFrame = false);
+    explicit Timecode(Formats format = HH_MM_SS_FF, double framesPerSecond = 25);
 
-    /** Set the current timecode format; this is the output format for this timecode. */
-    void setFormat(double framesPerSecond, bool dropFrame = false, Formats format = HH_MM_SS_FF) {
-        m_displayedFramesPerSecond = (int)(framesPerSecond + 0.5);
-        m_dropFrame = dropFrame;
-        m_format = format;
-        m_realFps = framesPerSecond;
-    }
+    /**
+     * Set the current timecode format; this is the output format for this timecode.
+     */
+    void setFormat(double framesPerSecond, Formats format = HH_MM_SS_FF);
 
     Formats format() const {
         return m_format;
@@ -49,27 +48,36 @@ public:
     ~Timecode();
 
     /** Returns the timecode for a given time */
+    QString getDisplayTimecode(const GenTime & time, bool frameDisplay) const;
     QString getTimecode(const GenTime & time) const;
+    int getDisplayFrameCount(const QString duration, bool frameDisplay) const;
     int getFrameCount(const QString duration) const;
     static QString getEasyTimecode(const GenTime & time, const double &fps);
     static QString getStringTimecode(int frames, const double &fps);
+    const QString getDisplayTimecodeFromFrames(int frames, bool frameDisplay) const;
     const QString getTimecodeFromFrames(int frames) const;
     double fps() const;
+    bool df() const;
+    const QValidator *validator() const;
+    QString reformatSeparators(QString duration) const;
 
 private:
     Formats m_format;
-    bool m_dropFrame;
+    bool m_dropFrameTimecode;
     int m_displayedFramesPerSecond;
     double m_realFps;
+    double m_dropFrames;
+    int m_framesPer10Minutes;
+    QRegExpValidator *m_validator;
 
     const QString getTimecodeHH_MM_SS_FF(const GenTime & time) const;
     const QString getTimecodeHH_MM_SS_FF(int frames) const;
 
-    QString getTimecodeHH_MM_SS_HH(const GenTime & time) const;
-    QString getTimecodeFrames(const GenTime & time) const;
-    QString getTimecodeSeconds(const GenTime & time) const;
-    QString getTimecodeDropFrame(const GenTime & time) const;
-    QString getTimecodeDropFrame(int frames) const;
+    const QString getTimecodeHH_MM_SS_HH(const GenTime & time) const;
+    const QString getTimecodeFrames(const GenTime & time) const;
+    const QString getTimecodeSeconds(const GenTime & time) const;
+    const QString getTimecodeDropFrame(const GenTime & time) const;
+    const QString getTimecodeDropFrame(int framenumber) const;
 };
 
 #endif
